@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1985, 1989, 1993, 1994, 2002
+ * Copyright (c) 1985, 1989, 1993, 1994
  *	The Regents of the University of California.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,16 +27,32 @@
  * SUCH DAMAGE.
  */
 
-#if 0
-static char sccsid[] = "@(#)main.c	8.6 (Berkeley) 10/9/94";
-#endif
+/* Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Free Software Foundation, Inc.
+
+   This file is part of GNU Inetutils.
+
+   GNU Inetutils is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
+
+   GNU Inetutils is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with GNU Inetutils; see the file COPYING.  If not, write
+   to the Free Software Foundation, Inc., 51 Franklin Street,
+   Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /*
  * FTP User Program -- Command Interface.
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
 /*#include <sys/ioctl.h>*/
@@ -45,6 +61,7 @@ static char sccsid[] = "@(#)main.c	8.6 (Berkeley) 10/9/94";
 
 #include <arpa/ftp.h>
 
+#include <argp.h>
 #include <ctype.h>
 #include <error.h>
 #include <netdb.h>
@@ -52,146 +69,126 @@ static char sccsid[] = "@(#)main.c	8.6 (Berkeley) 10/9/94";
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
-#include <getopt.h>
 
 /* Define macro to nothing so declarations in ftp_var.h become definitions. */
 #define FTP_EXTERN
 #include "ftp_var.h"
 
-#if HAVE_READLINE_READLINE_H
-# include <readline/readline.h>
-#endif
+#include "libinetutils.h"
 
+#if HAVE_LIBREADLINE
+#  include <readline/readline.h>
+#else
+#  include "readline.h"
+#endif
 
-char *program_name;
 
 #define DEFAULT_PROMPT "ftp> "
 static char *prompt = 0;
 
-static void
-usage (int err)
-{
-  if (err != 0)
-    {
-      fprintf (stderr, "Usage: %s [OPTION...] [HOST [PORT]]\n", program_name);
-      fprintf (stderr, "Try `%s --help' for more information.\n", program_name);
-    }
-  else
-    {
-      fprintf (stdout, "Usage: %s [OPTION...] [HOST [PORT]]\n", program_name);
-      puts ("Remote file transfer.\n\n\
-  -d, --debug                Turn on debugging mode\n\
-  -g, --no-glob              Turn off file name globbing\n\
-  -i, --no-prompt            Don't prompt during multiple-file transfers\n\
-  -n, --no-login             Don't automatically login to the remove system\n\
-  -t, --trace                Enable packet tracing\n\
-  -p, --prompt[=PROMPT]      Print a command-line prompt (optionally PROMPT),\n\
-                             even if not on a tty\n\
-  -v, --verbose              Be verbose\n\
-      --help                 Give this help list\n\
-  -V, --version              Print program version");
+ARGP_PROGRAM_DATA_SIMPLE ("ftp", "2007");
 
-      fprintf (stdout, "\nSubmit bug reports to %s.\n", PACKAGE_BUGREPORT);
+const char args_doc[] = "[HOST [PORT]]";
+const char doc[] = "Remote file transfer.";
+
+static struct argp_option argp_options[] = {
+#define GRP 0
+  {"debug", 'd', NULL, 0, "Set the SO_DEBUG option", GRP+1},
+  {"no-glob", 'g', NULL, 0, "Turn off file name globbing", GRP+1},
+  {"no-prompt", 'i', NULL, 0, "Don't prompt during multiple file transfers",
+   GRP+1},
+  {"no-login", 'n', NULL, 0, "Don't automatically login to the remote system",
+   GRP+1},
+  {"trace", 't', NULL, 0, "Enable packet tracing", GRP+1},
+  {"prompt", 'p', "PROMPT", OPTION_ARG_OPTIONAL, "Print a command line PROMPT "
+   "(optionally), even if not on a tty", GRP+1},
+  {"verbose", 'v', NULL, 0, "Verbose output", GRP+1},
+#undef GRP
+  {NULL}
+};
+
+static error_t
+parse_opt (int key, char *arg, struct argp_state *state)
+{
+  switch (key)
+    {
+    case 'd':		/* Enable debug mode.  */
+      options |= SO_DEBUG;
+      debug++;
+      break;
+
+    case 'g':		/* No glob.  */
+      doglob = 0;
+      break;
+
+    case 'i':		/* No prompt.  */
+      interactive = 0;
+      break;
+
+    case 'n':		/* No automatic login.  */
+      autologin = 0;
+      break;
+
+    case 't':		/* Enable packet tracing.  */
+      trace++;
+      break;
+
+    case 'v':		/* Verbose.  */
+      verbose++;
+      break;
+
+    case 'p':		/* Print command line prompt.  */
+      prompt = arg ? arg : DEFAULT_PROMPT;
+      break;
+
+    default:
+      return ARGP_ERR_UNKNOWN;
     }
-  exit (err);
+
+  return 0;
 }
 
-static const char *short_options = "dginp::tv";
-static struct option long_options[] =
-{
-  { "trace", no_argument, 0, 't' },
-  { "verbose", no_argument, 0, 'v' },
-  { "no-login", no_argument, 0, 'n' },
-  { "no-prompt", no_argument, 0, 'i' },
-  { "debug", no_argument, 0, 'd' },
-  { "no-glob", no_argument, 0, 'g' },
-  { "help", no_argument, 0, '&' },
-  { "prompt", optional_argument, 0, 'p' },
-  { "version", no_argument, 0, 'V' },
-  { 0 }
-};
+static struct argp argp = {argp_options, parse_opt, args_doc, doc};
 
+
 int
 main (int argc, char *argv[])
 {
-  int ch, top;
+  int top;
+  int index;
   struct passwd *pw = NULL;
   char *cp;
 
-  program_name = argv[0];
-
+  set_program_name (argv[0]);
+  
   sp = getservbyname ("ftp", "tcp");
   if (sp == 0)
-    error (1, 0, "ftp/tcp: unknown service");
+    error (EXIT_FAILURE, 0, "ftp/tcp: unknown service");
   doglob = 1;
   interactive = 1;
   autologin = 1;
 
-  while ((ch = getopt_long (argc, argv, short_options, long_options, 0))
-	 != EOF)
-    {
-      switch (ch) {
-      case 'd': /* Enable ebug mode.  */
-	options |= SO_DEBUG;
-	debug++;
-	break;
+  /* Parse command line */
+  argp_parse (&argp, argc, argv, 0, &index, NULL);
 
-      case 'g': /* No glob.  */
-	doglob = 0;
-	break;
-
-      case 'i': /* No prompt.  */
-	interactive = 0;
-	break;
-
-      case 'n': /* No automatic login.  */
-	autologin = 0;
-	break;
-
-      case 't': /* Enable packet tracing.  */
-	trace++;
-	break;
-
-      case 'v': /* Verbose.  */
-	verbose++;
-	break;
-
-      case 'p': /* Print command line prompt.  */
-	prompt = optarg ? optarg : DEFAULT_PROMPT;
-	break;
-
-      case '&': /* Usage.  */
-	usage (0);
-	/* Not reached.  */
-
-      case 'V': /* Version.  */
-	printf ("ftp (%s) %s\n", PACKAGE_NAME, PACKAGE_VERSION);
-	exit (0);
-
-      case '?':
-      default:
-	usage (1);
-	/* Not reached.  */
-      }
-    }
-
-  argc -= optind;
-  argv += optind;
+  argc -= index;
+  argv += index;
 
   fromatty = isatty (fileno (stdin));
   if (fromatty)
     {
       verbose++;
-      if (! prompt)
+      if (!prompt)
 	prompt = DEFAULT_PROMPT;
     }
 
-  cpend = 0;	/* no pending replies */
-  proxy = 0;	/* proxy not active */
-  passivemode = 0; /* passive mode not active */
-  crflag = 1;	/* strip c.r. on ascii gets */
-  sendport = -1;	/* not using ports */
+  cpend = 0;			/* no pending replies */
+  proxy = 0;			/* proxy not active */
+  passivemode = 0;		/* passive mode not active */
+  crflag = 1;			/* strip c.r. on ascii gets */
+  sendport = -1;		/* not using ports */
   /*
    * Set up the home directory in case we're globbing.
    */
@@ -199,7 +196,7 @@ main (int argc, char *argv[])
   if (cp != NULL)
     pw = getpwnam (cp);
   if (pw == NULL)
-    pw = getpwuid(getuid());
+    pw = getpwuid (getuid ());
   if (pw != NULL)
     {
       char *buf = malloc (strlen (pw->pw_dir) + 1);
@@ -214,15 +211,15 @@ main (int argc, char *argv[])
       char *xargv[5];
 
       if (setjmp (toplevel))
-	exit (0);
-      signal(SIGINT, intr);
-      signal(SIGPIPE, lostpeer);
-      xargv[0] = program_name;
+	exit (EXIT_SUCCESS);
+      signal (SIGINT, intr);
+      signal (SIGPIPE, lostpeer);
+      xargv[0] = program_invocation_name;
       xargv[1] = argv[0];
       xargv[2] = argv[1];
       xargv[3] = argv[2];
       xargv[4] = NULL;
-      setpeer (argc+1, xargv);
+      setpeer (argc + 1, xargv);
     }
   top = setjmp (toplevel) == 0;
   if (top)
@@ -232,7 +229,7 @@ main (int argc, char *argv[])
     }
   for (;;)
     {
-      cmdscanner(top);
+      cmdscanner (top);
       top = 1;
     }
 }
@@ -250,13 +247,13 @@ lostpeer (int sig ARG_UNUSED)
     {
       if (cout != NULL)
 	{
-	  shutdown (fileno (cout), 1+1);
+	  shutdown (fileno (cout), 1 + 1);
 	  fclose (cout);
 	  cout = NULL;
 	}
       if (data >= 0)
 	{
-	  shutdown (data, 1+1);
+	  shutdown (data, 1 + 1);
 	  close (data);
 	  data = -1;
 	}
@@ -267,7 +264,7 @@ lostpeer (int sig ARG_UNUSED)
     {
       if (cout != NULL)
 	{
-	  shutdown (fileno(cout), 1+1);
+	  shutdown (fileno (cout), 1 + 1);
 	  fclose (cout);
 	  cout = NULL;
 	}
@@ -309,52 +306,29 @@ cmdscanner (int top)
     putchar ('\n');
   for (;;)
     {
-
-#if HAVE_LIBREADLINE
       if (line)
 	{
 	  free (line);
-	  line = 0;
+	  line = NULL;
 	}
       line = readline (prompt);
       if (!line)
 	quit (0, 0);
       l = strlen (line);
       if (l >= MAXLINE)
-        {
-          printf("Line too long.\n");
-          break;
-        }
-      if (line && *line)
-	add_history (line);
-      if (l == 0)
-	break;
-#else
-      if (prompt)
 	{
-	  printf ("%s",prompt);
-	  fflush(stdout);
+	  printf ("Line too long.\n");
+	  break;
 	}
 
-      if (fgets (line, sizeof line, stdin) == NULL)
-	quit(0, 0);
-      l = strlen (line);
+#if HAVE_LIBHISTORY
+      if (line && *line)
+	add_history (line);
+#endif
+
       if (l == 0)
 	break;
-      if (line[--l] == '\n')
-	{
-	  if (l == 0)
-	    break;
-	  line[l] = '\0';
-	}
-      else if (l == sizeof (line) - 2)
-	{
-	  printf ("sorry, input line too long\n");
-	  while ((l = getchar ()) != '\n' && l != EOF)
-				/* void */;
-	  break;
-	} /* else it was a line without a newline */
-#endif
+
       makeargv ();
       if (margc == 0)
 	continue;
@@ -377,7 +351,7 @@ cmdscanner (int top)
 	}
       (*c->c_handler) (margc, margv);
       if (bell && c->c_bell)
-	putchar('\007');
+	putchar ('\007');
       if (c->c_handler != help)
 	break;
     }
@@ -418,26 +392,26 @@ slurpstring ()
   char *ap = argbase;
   char *tmp = argbase;		/* will return this if token found */
 
-  if (*sb == '!' || *sb == '$') {	/* recognize ! as a token for shell */
-    switch (slrflag)	/* and $ as token for macro invoke */
-      {
-      case 0:
-	slrflag++;
-	stringbase++;
-	return ((*sb == '!') ? "!" : "$");
-	/* NOTREACHED */
+  if (*sb == '!' || *sb == '$')
+    {				/* recognize ! as a token for shell */
+      switch (slrflag)		/* and $ as token for macro invoke */
+	{
+	case 0:
+	  slrflag++;
+	  stringbase++;
+	  return ((*sb == '!') ? "!" : "$");
 
-      case 1:
-	slrflag++;
-	altarg = stringbase;
-	break;
-      
-      default:
-	break;
-      }
-  }
+	case 1:
+	  slrflag++;
+	  altarg = stringbase;
+	  break;
 
- S0:
+	default:
+	  break;
+	}
+    }
+
+S0:
   switch (*sb)
     {
     case '\0':
@@ -445,7 +419,8 @@ slurpstring ()
 
     case ' ':
     case '\t':
-      sb++; goto S0;
+      sb++;
+      goto S0;
 
     default:
       switch (slrflag)
@@ -465,54 +440,57 @@ slurpstring ()
       goto S1;
     }
 
- S1:
+S1:
   switch (*sb)
     {
     case ' ':
     case '\t':
     case '\0':
-      goto OUT;	/* end of token */
+      goto OUT;			/* end of token */
 
     case '\\':
-      sb++; goto S2;	/* slurp next character */
+      sb++;
+      goto S2;			/* slurp next character */
 
     case '"':
-      sb++; goto S3;	/* slurp quoted string */
+      sb++;
+      goto S3;			/* slurp quoted string */
 
     default:
-      *ap++ = *sb++;	/* add character to token */
+      *ap++ = *sb++;		/* add character to token */
       got_one = 1;
       goto S1;
     }
 
- S2:
+S2:
   switch (*sb)
     {
     case '\0':
       goto OUT;
-      
+
     default:
       *ap++ = *sb++;
       got_one = 1;
       goto S1;
     }
 
- S3:
+S3:
   switch (*sb)
     {
     case '\0':
       goto OUT;
-      
+
     case '"':
-      sb++; goto S1;
-      
+      sb++;
+      goto S1;
+
     default:
       *ap++ = *sb++;
       got_one = 1;
       goto S3;
     }
 
- OUT:
+OUT:
   if (got_one)
     *ap++ = '\0';
   argbase = ap;			/* update storage pointer */
@@ -535,4 +513,3 @@ slurpstring ()
     }
   return ((char *) 0);
 }
-
