@@ -29,46 +29,67 @@
  *	@(#)extern.h	8.2 (Berkeley) 4/4/94
  */
 
+/* Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Free Software Foundation, Inc.
+
+   This file is part of GNU Inetutils.
+
+   GNU Inetutils is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
+
+   GNU Inetutils is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with GNU Inetutils; see the file COPYING.  If not, write
+   to the Free Software Foundation, Inc., 51 Franklin Street,
+   Fifth Floor, Boston, MA 02110-1301 USA. */
+
 #include <stdio.h>
 #include <setjmp.h>
+#include <getopt.h>
 #include <sys/types.h>
 
-extern void cwd            (const char *);
-extern int  checkuser      (const char *filename, const char *name);
-extern void delete         (const char *);
-extern int  display_file   (const char *name, int code);
-extern void dologout       (int);
-extern void fatal          (const char *);
-extern int  ftpd_pclose    (FILE *);
-extern FILE *ftpd_popen    (char *, const char *);
+extern void cwd (const char *);
+extern int checkuser (const char *filename, const char *name);
+extern void delete (const char *);
+extern int display_file (const char *name, int code);
+extern void dologout (int);
+extern void fatal (const char *);
+extern int ftpd_pclose (FILE *);
+extern FILE *ftpd_popen (char *, const char *);
 #if !HAVE_DECL_GETUSERSHELL
-extern char *getusershell  (void);
+extern char *getusershell (void);
 #endif
-extern void lreply         (int, const char *, ...);
-extern void makedir        (const char *);
-extern void nack           (const char *);
-extern void pass           (const char *);
-extern void passive        (void);
-extern void perror_reply   (int, const char *);
-extern void pwd            (void);
-extern void removedir      (const char *);
-extern void renamecmd      (const char *, const char *);
-extern char *renamefrom    (const char *);
-extern void reply          (int, const char *, ...);
-extern void retrieve       (const char *, const char *);
+extern void lreply (int, const char *, ...);
+extern void makedir (const char *);
+extern void nack (const char *);
+extern void pass (const char *);
+extern void passive (void);
+extern void perror_reply (int, const char *);
+extern void pwd (void);
+extern void removedir (const char *);
+extern void renamecmd (const char *, const char *);
+extern char *renamefrom (const char *);
+extern void reply (int, const char *, ...);
+extern void retrieve (const char *, const char *);
 extern void send_file_list (const char *);
-extern void setproctitle   (const char *, ...);
-extern void statcmd        (void);
-extern void statfilecmd    (const char *);
-extern void store          (const char *, const char *, int);
-extern void toolong        (int);
-extern char *telnet_fgets  (char *, int, FILE *);
-extern void upper          (char *);
-extern void user           (const char *);
-extern char *sgetsave      (const char *);
+extern void setproctitle (const char *, ...);
+extern void statcmd (void);
+extern void statfilecmd (const char *);
+extern void store (const char *, const char *, int);
+extern void toolong (int);
+extern char *telnet_fgets (char *, int, FILE *);
+extern void upper (char *);
+extern void user (const char *);
+extern char *sgetsave (const char *);
 
 /* Exported from ftpd.c.  */
-jmp_buf  errcatch;
+jmp_buf errcatch;
 extern struct sockaddr_in data_dest;
 extern struct sockaddr_in his_addr;
 extern int logged_in;
@@ -103,7 +124,7 @@ struct credentials
   char *remotehost;
   char *passwd;
   char *pass;
-  char *message; /* Sending back custom messages.  */
+  char *message;		/* Sending back custom messages.  */
   uid_t uid;
   gid_t gid;
   int guest;
@@ -118,12 +139,12 @@ struct credentials
 };
 
 extern struct credentials cred;
-extern int  sgetcred       (const char *, struct credentials *);
-extern int  auth_user      (const char *, struct credentials *);
-extern int  auth_pass      (const char *, struct credentials *);
+extern int sgetcred (const char *, struct credentials *);
+extern int auth_user (const char *, struct credentials *);
+extern int auth_pass (const char *, struct credentials *);
 
 /* Exported from pam.c */
 #ifdef WITH_PAM
-extern int  pam_user       (const char *, struct credentials *);
-extern int  pam_pass       (const char *, struct credentials *);
+extern int pam_user (const char *, struct credentials *);
+extern int pam_pass (const char *, struct credentials *);
 #endif
