@@ -1,13 +1,13 @@
 /*
  SYSVish version:
 
-Copyright (C) 1996, 2000 Free Software Foundation, Inc.
+Copyright (C) 1996, 2000, 2007 Free Software Foundation, Inc.
 This file is part of the GNU C Library.
 Contributed by Ulrich Drepper <drepper@cygnus.com>, 1996.
 
 The GNU C Library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License as
-published by the Free Software Foundation; either version 2 of the
+published by the Free Software Foundation; either version 3 of the
 License, or (at your option) any later version.
 
 The GNU C Library is distributed in the hope that it will be useful,
@@ -55,12 +55,8 @@ Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *  
  */
 
-#ifndef lint
-static char sccsid[] = "@(#)logwtmp.c	8.1 (Berkeley) 6/4/93";
-#endif /* not lint */
-
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
 #include <sys/types.h>
@@ -75,7 +71,7 @@ static char sccsid[] = "@(#)logwtmp.c	8.1 (Berkeley) 6/4/93";
 #include "extern.h"
 
 #if !defined (_PATH_WTMP) && defined (WTMP_FILE)
-#define _PATH_WTMP WTMP_FILE
+# define _PATH_WTMP WTMP_FILE
 #endif
 
 /*
@@ -84,7 +80,7 @@ static char sccsid[] = "@(#)logwtmp.c	8.1 (Berkeley) 6/4/93";
  * after login, but before logout).
  */
 void
-logwtmp(const char *line, const char *name, const char *host)
+logwtmp (const char *line, const char *name, const char *host)
 {
   struct utmp ut;
 
@@ -132,17 +128,18 @@ logwtmp(const char *line, const char *name, const char *host)
 #else
   /* Do things the old way.  */
   {
-	struct utmp ut;
-	struct stat buf;
-	static int fd = -1;
+    struct utmp ut;
+    struct stat buf;
+    static int fd = -1;
 
-	if (fd < 0 && (fd = open(_PATH_WTMP, O_WRONLY|O_APPEND, 0)) < 0)
-		return;
-	if (fstat(fd, &buf) == 0) {
-		if (write(fd, (char *)&ut, sizeof(struct utmp)) !=
-		    sizeof(struct utmp))
-			(void)ftruncate(fd, buf.st_size);
-	}
+    if (fd < 0 && (fd = open (_PATH_WTMP, O_WRONLY | O_APPEND, 0)) < 0)
+      return;
+    if (fstat (fd, &buf) == 0)
+      {
+	if (write (fd, (char *) &ut, sizeof (struct utmp)) !=
+	    sizeof (struct utmp))
+	  ftruncate (fd, buf.st_size);
+      }
   }
 #endif
 }
