@@ -1,5 +1,5 @@
 /* argcv.c - simple functions for parsing input based on whitespace
-   Copyright (C) 1999, 2000, 2001, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2007, 2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #include "argcv.h"
+#include <ctype.h>
 
 /*
  * takes a string and splits it into several strings, breaking at ' '
@@ -45,22 +46,20 @@ argcv_scan (int len, const char *command, const char *delim,
     case '\'':
       while (++i < len && command[i] != command[*start])
 	;
-      if (i < len)  /* found matching quote */
+      if (i < len)		/* found matching quote */
 	break;
-      /*FALLTHRU*/
     default:
-      if (isdelim (command [i], delim))
+      if (isdelim (command[i], delim))
 	break;
       /* Skip until next whitespace character or end of line */
-      while (++i < len &&
-	     !(isws (command [i]) || isdelim (command [i], delim)))
+      while (++i < len && !(isws (command[i]) || isdelim (command[i], delim)))
 	;
       i--;
       break;
     }
 
   *end = i;
-  *save = i+1;
+  *save = i + 1;
   return *save;
 }
 
@@ -68,13 +67,13 @@ int
 argcv_get (const char *command, const char *delim, int *argc, char ***argv)
 {
   int len = strlen (command);
-  int i = 0, j = 0;
+  int i = 0;
   int start, end, save;
 
   *argc = 0;
   *argv = NULL;
 
-  while (len > 0 && isspace (command[len-1]))
+  while (len > 0 && isspace (command[len - 1]))
     len--;
   if (len < 1)
     return 1;
@@ -83,7 +82,7 @@ argcv_get (const char *command, const char *delim, int *argc, char ***argv)
   *argc = 1;
   save = 0;
   while (argcv_scan (len, command, delim, &start, &end, &save) < len)
-      (*argc)++;
+    (*argc)++;
 
   *argv = calloc ((*argc + 1), sizeof (char *));
 
@@ -105,7 +104,7 @@ argcv_get (const char *command, const char *delim, int *argc, char ***argv)
 	  end--;
 	}
       n = end - start + 1;
-      (*argv)[i] = calloc (n+1,  sizeof (char));
+      (*argv)[i] = calloc (n + 1, sizeof (char));
       if ((*argv)[i] == NULL)
 	return 1;
       memcpy ((*argv)[i], &command[start], n);
@@ -175,7 +174,7 @@ argcv_string (int argc, char **argv, char **pstring)
 #if 0
 char *command = "set prompt=\"& \"";
 
-main()
+main ()
 {
   int i, argc;
   char **argv;
