@@ -27,17 +27,13 @@
  * SUCH DAMAGE.
  */
 
-#ifndef lint
-static char sccsid[] = "@(#)genget.c	8.2 (Berkeley) 5/30/95";
-#endif /* not lint */
-
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
 #include <ctype.h>
 
-#define	LOWER(x) (isupper(x) ? tolower(x) : (x))
+#define LOWER(x) (isupper(x) ? tolower(x) : (x))
 /*
  * The prefix function returns 0 if *s1 is not a prefix
  * of *s2.  If *s1 exactly matches *s2, the negative of
@@ -45,23 +41,24 @@ static char sccsid[] = "@(#)genget.c	8.2 (Berkeley) 5/30/95";
  * the length of *s1 is returned.
  */
 int
-isprefix(register char *s1, register char *s2)
+isprefix (register char *s1, register char *s2)
 {
-        char *os1;
-	register char c1, c2;
+  char *os1;
+  register char c1, c2;
 
-        if (*s1 == '\0')
-                return(-1);
-        os1 = s1;
-	c1 = *s1;
-	c2 = *s2;
-        while (LOWER(c1) == LOWER(c2)) {
-		if (c1 == '\0')
-			break;
-                c1 = *++s1;
-                c2 = *++s2;
-        }
-        return(*s1 ? 0 : (*s2 ? (s1 - os1) : (os1 - s1)));
+  if (*s1 == '\0')
+    return (-1);
+  os1 = s1;
+  c1 = *s1;
+  c2 = *s2;
+  while (LOWER (c1) == LOWER (c2))
+    {
+      if (c1 == '\0')
+	break;
+      c1 = *++s1;
+      c2 = *++s2;
+    }
+  return (*s1 ? 0 : (*s2 ? (s1 - os1) : (os1 - s1)));
 }
 
 static char *ambiguous;		/* special return value for command routines */
@@ -69,32 +66,33 @@ static char *ambiguous;		/* special return value for command routines */
 /* char	*name; name to match */
 /* char	**table; name entry in table */
 char **
-genget(char	*name, char	**table, int	stlen)
+genget (char *name, char **table, int stlen)
 {
-	register char **c, **found;
-	register int n;
+  register char **c, **found;
+  register int n;
 
-	if (name == 0)
-	    return 0;
+  if (name == 0)
+    return 0;
 
-	found = 0;
-	for (c = table; *c != 0; c = (char **)((char *)c + stlen)) {
-		if ((n = isprefix(name, *c)) == 0)
-			continue;
-		if (n < 0)		/* exact match */
-			return(c);
-		if (found)
-			return(&ambiguous);
-		found = c;
-	}
-	return(found);
+  found = 0;
+  for (c = table; *c != 0; c = (char **) ((char *) c + stlen))
+    {
+      if ((n = isprefix (name, *c)) == 0)
+	continue;
+      if (n < 0)		/* exact match */
+	return (c);
+      if (found)
+	return (&ambiguous);
+      found = c;
+    }
+  return (found);
 }
 
 /*
  * Function call version of Ambiguous()
  */
 int
-Ambiguous(char *s)
+Ambiguous (char *s)
 {
-	return((char **)s == &ambiguous);
+  return ((char **) s == &ambiguous);
 }
