@@ -18,71 +18,71 @@
    Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
 #ifdef KRB5
-#include <stdlib.h>
-#include <stdio.h>
-#include <arpa/telnet.h>
-#include <krb5.h>
-#include <assert.h>
+# include <stdlib.h>
+# include <stdio.h>
+# include <arpa/telnet.h>
+# include <krb5.h>
+# include <assert.h>
 
-#include <com_err.h>
-#include <netdb.h>
-#include <ctype.h>
-#include <syslog.h>
-#ifdef  HAVE_STRING_H
-# include <string.h>
-#else
-# include <strings.h>
-#endif
+# include <com_err.h>
+# include <netdb.h>
+# include <ctype.h>
+# include <syslog.h>
+# ifdef  HAVE_STRING_H
+#  include <string.h>
+# else
+#  include <strings.h>
+# endif
 
-#include "auth.h"
-#include "misc.h"
+# include "auth.h"
+# include "misc.h"
 
-#ifndef KRB5_ENV_CCNAME
-# define KRB5_ENV_CCNAME "KRB5CCNAME"
-#endif
+# ifndef KRB5_ENV_CCNAME
+#  define KRB5_ENV_CCNAME "KRB5CCNAME"
+# endif
 
-#ifdef  ENCRYPTION
-#include "encrypt.h"
-#endif
+# ifdef  ENCRYPTION
+#  include "encrypt.h"
+# endif
 
-#ifdef  FORWARD
+# ifdef  FORWARD
 /* FIXME: This is set directly from telnet/main.c */
-int forward_flags = 0;  
-extern int net; /*FIXME*/
-
-void kerberos5_forward ();
-#endif  /* FORWARD */
+int forward_flags = 0;
+extern int net;
+ /*FIXME*/ void kerberos5_forward ();
+# endif	/* FORWARD */
 
 static unsigned char str_data[2048] = { IAC, SB, TELOPT_AUTHENTICATION, 0,
-					AUTHTYPE_KERBEROS_V5, };
+  AUTHTYPE_KERBEROS_V5,
+};
 
-#define KRB_AUTH             0       /* Authentication data follows */
-#define KRB_REJECT           1       /* Rejected (reason might follow) */
-#define KRB_ACCEPT           2       /* Accepted */
-#define KRB_RESPONSE         3       /* Response for mutual auth. */
-#define KRB_FORWARD          4       /* Forwarded credentials follow */
-#define KRB_FORWARD_ACCEPT   5       /* Forwarded credentials accepted */
-#define KRB_FORWARD_REJECT   6       /* Forwarded credentials rejected */
+# define KRB_AUTH             0	/* Authentication data follows */
+# define KRB_REJECT           1	/* Rejected (reason might follow) */
+# define KRB_ACCEPT           2	/* Accepted */
+# define KRB_RESPONSE         3	/* Response for mutual auth. */
+# define KRB_FORWARD          4	/* Forwarded credentials follow */
+# define KRB_FORWARD_ACCEPT   5	/* Forwarded credentials accepted */
+# define KRB_FORWARD_REJECT   6	/* Forwarded credentials rejected */
 
 krb5_auth_context auth_context = 0;
 krb5_context telnet_context = 0;
 
-static  krb5_data auth; /* session key for telnet */
-static  krb5_ticket *ticket = NULL; /* telnet matches the AP_REQ and
-				       AP_REP with this */
+static krb5_data auth;		/* session key for telnet */
+static krb5_ticket *ticket = NULL;	/* telnet matches the AP_REQ and
+					   AP_REP with this */
 
-krb5_keyblock   *session_key = 0;
+krb5_keyblock *session_key = 0;
 char *telnet_srvtab = NULL;
 char *telnet_krb5_realm = NULL;
 
-#define DEBUG(c) if (auth_debug_mode) printf c
+# define DEBUG(c) if (auth_debug_mode) printf c
 
 static int
-Data (TN_Authenticator *ap, int type, krb5_pointer d, int c)
+Data (TN_Authenticator * ap, int type, krb5_pointer d, int c)
 {
   unsigned char *p = str_data + 4;
   unsigned char *cd = (unsigned char *) d;
@@ -94,8 +94,7 @@ Data (TN_Authenticator *ap, int type, krb5_pointer d, int c)
     {
       printf ("%s:%d: [%d] (%d)",
 	      str_data[3] == TELQUAL_IS ? ">>>IS" : ">>>REPLY",
-	      str_data[3],
-	      type, c);
+	      str_data[3], type, c);
       printd (d, c);
       printf ("\r\n");
     }
@@ -104,10 +103,11 @@ Data (TN_Authenticator *ap, int type, krb5_pointer d, int c)
   *p++ = ap->way;
   *p++ = type;
 
-  while (c-- > 0) {
-    if ((*p++ = *cd++) == IAC)
-      *p++ = IAC;
-  }
+  while (c-- > 0)
+    {
+      if ((*p++ = *cd++) == IAC)
+	*p++ = IAC;
+    }
   *p++ = IAC;
   *p++ = SE;
   if (str_data[3] == TELQUAL_IS)
@@ -117,10 +117,10 @@ Data (TN_Authenticator *ap, int type, krb5_pointer d, int c)
 
 /* FIXME: Reverse return code! */
 int
-kerberos5_init (TN_Authenticator *ap, int server)
+kerberos5_init (TN_Authenticator * ap, int server)
 {
   str_data[3] = server ? TELQUAL_REPLY : TELQUAL_IS;
-  if (telnet_context == 0 && krb5_init_context(&telnet_context))
+  if (telnet_context == 0 && krb5_init_context (&telnet_context))
     return 0;
   return 1;
 }
@@ -139,19 +139,19 @@ kerberos5_cleanup ()
     {
       if (!krb5_cc_resolve (telnet_context, ccname, &ccache))
 	krb5_cc_destroy (telnet_context, ccache);
-  }
+    }
 
   krb5_free_context (telnet_context);
   telnet_context = 0;
 }
 
-#ifdef  ENCRYPTION
+# ifdef  ENCRYPTION
 
 void
-encryption_init (krb5_creds *creds)
+encryption_init (krb5_creds * creds)
 {
   krb5_keyblock *newkey = 0;
-  
+
   krb5_auth_con_getlocalsubkey (telnet_context, auth_context, &newkey);
   if (session_key)
     {
@@ -178,25 +178,25 @@ encryption_init (krb5_creds *creds)
 	      break;
 
 	    default:
-	      DEBUG(("can't determine which keyblock to use"));
-	      /*FIXME: abort?*/
+	      DEBUG (("can't determine which keyblock to use"));
+	      /*FIXME: abort? */
 	    }
 	}
 
-      krb5_free_keyblock(telnet_context, newkey);
+      krb5_free_keyblock (telnet_context, newkey);
     }
 }
 
-#else
-# define encryption_init(c)
-#endif
+# else
+#  define encryption_init(c)
+# endif
 
 int
-kerberos5_send (TN_Authenticator *ap)
+kerberos5_send (TN_Authenticator * ap)
 {
   krb5_error_code r;
   krb5_ccache ccache;
-  krb5_creds creds; 
+  krb5_creds creds;
   krb5_creds *new_creds = 0;
   int ap_opts;
   char type_check[2];
@@ -204,23 +204,21 @@ kerberos5_send (TN_Authenticator *ap)
 
   if (!UserNameRequested)
     {
-      DEBUG(("telnet: Kerberos V5: no user name supplied\r\n"));
+      DEBUG (("telnet: Kerberos V5: no user name supplied\r\n"));
       return 0;
     }
 
   if ((r = krb5_cc_default (telnet_context, &ccache)))
     {
-      DEBUG(("telnet: Kerberos V5: could not get default ccache\r\n"));
+      DEBUG (("telnet: Kerberos V5: could not get default ccache\r\n"));
       return 0;
     }
 
   memset (&creds, 0, sizeof (creds));
   if ((r = krb5_sname_to_principal (telnet_context, RemoteHostName,
-				    "host", KRB5_NT_SRV_HST,
-				    &creds.server)))
+				    "host", KRB5_NT_SRV_HST, &creds.server)))
     {
-      DEBUG(("telnet: Kerberos V5: error while constructing service name: %s\r\n",
-	     error_message(r)));
+      DEBUG (("telnet: Kerberos V5: error while constructing service name: %s\r\n", error_message (r)));
       return 0;
     }
 
@@ -235,11 +233,10 @@ kerberos5_send (TN_Authenticator *ap)
       krb5_princ_set_realm (telnet_context, creds.server, &rdata);
     }
 
-  if ((r = krb5_cc_get_principal (telnet_context, ccache,
-				  &creds.client)))
+  if ((r = krb5_cc_get_principal (telnet_context, ccache, &creds.client)))
     {
-      DEBUG(("telnet: Kerberos V5: failure on principal (%s)\r\n",
-	     error_message(r)));
+      DEBUG (("telnet: Kerberos V5: failure on principal (%s)\r\n",
+	      error_message (r)));
       krb5_free_cred_contents (telnet_context, &creds);
       return 0;
     }
@@ -248,8 +245,8 @@ kerberos5_send (TN_Authenticator *ap)
   if ((r = krb5_get_credentials (telnet_context, 0,
 				 ccache, &creds, &new_creds)))
     {
-      DEBUG(("telnet: Kerberos V5: failure on credentials(%s)\r\n",
-	     error_message(r)));
+      DEBUG (("telnet: Kerberos V5: failure on credentials(%s)\r\n",
+	      error_message (r)));
       krb5_free_cred_contents (telnet_context, &creds);
       return 0;
     }
@@ -259,20 +256,20 @@ kerberos5_send (TN_Authenticator *ap)
   else
     ap_opts = 0;
 
-#ifdef ENCRYPTION
+# ifdef ENCRYPTION
   ap_opts |= AP_OPTS_USE_SUBKEY;
-#endif 
+# endif
 
   if (auth_context)
     {
       krb5_auth_con_free (telnet_context, auth_context);
       auth_context = 0;
     }
-  
+
   if ((r = krb5_auth_con_init (telnet_context, &auth_context)))
     {
-      DEBUG(("Kerberos V5: failed to init auth_context (%s)\r\n",
-	     error_message(r)));
+      DEBUG (("Kerberos V5: failed to init auth_context (%s)\r\n",
+	      error_message (r)));
       return 0;
     }
 
@@ -289,36 +286,36 @@ kerberos5_send (TN_Authenticator *ap)
 			    &check_data, new_creds, &auth);
 
   encryption_init (new_creds);
-  
+
   krb5_free_cred_contents (telnet_context, &creds);
   krb5_free_creds (telnet_context, new_creds);
   if (r)
     {
-      DEBUG(("telnet: Kerberos V5: mk_req failed (%s)\r\n",
-	     error_message(r)));
+      DEBUG (("telnet: Kerberos V5: mk_req failed (%s)\r\n",
+	      error_message (r)));
       return 0;
     }
 
   if (!auth_sendname (UserNameRequested, strlen (UserNameRequested)))
     {
-      DEBUG(("telnet: Not enough room for user name\r\n"));
+      DEBUG (("telnet: Not enough room for user name\r\n"));
       return 0;
     }
 
   if (!Data (ap, KRB_AUTH, auth.data, auth.length))
     {
-      DEBUG(("telnet: Not enough room for authentication data\r\n"));
+      DEBUG (("telnet: Not enough room for authentication data\r\n"));
       return 0;
     }
 
-  DEBUG(("telnet: Sent Kerberos V5 credentials to server\r\n"));
+  DEBUG (("telnet: Sent Kerberos V5 credentials to server\r\n"));
 
   return 1;
 }
 
-#ifdef ENCRYPTION
+# ifdef ENCRYPTION
 void
-telnet_encrypt_key (Session_Key *skey)
+telnet_encrypt_key (Session_Key * skey)
 {
   if (session_key)
     {
@@ -328,30 +325,30 @@ telnet_encrypt_key (Session_Key *skey)
       encrypt_session_key (skey, 0);
     }
 }
-#else
-# define telnet_encrypt_key(s)
-#endif
+# else
+#  define telnet_encrypt_key(s)
+# endif
 
 void
-kerberos5_reply (TN_Authenticator *ap, unsigned char *data, int cnt)
+kerberos5_reply (TN_Authenticator * ap, unsigned char *data, int cnt)
 {
-#ifdef ENCRYPTION
+# ifdef ENCRYPTION
   Session_Key skey;
-#endif
+# endif
   static int mutual_complete = 0;
 
   if (cnt-- < 1)
     return;
-  
+
   switch (*data++)
     {
     case KRB_REJECT:
-      if (cnt > 0) 
+      if (cnt > 0)
 	printf ("[ Kerberos V5 refuses authentication because %.*s ]\r\n",
-	       cnt, data);
+		cnt, data);
       else
 	printf ("[ Kerberos V5 refuses authentication ]\r\n");
-      auth_send_retry();
+      auth_send_retry ();
       return;
 
     case KRB_ACCEPT:
@@ -359,7 +356,8 @@ kerberos5_reply (TN_Authenticator *ap, unsigned char *data, int cnt)
 	{
 	  if ((ap->way & AUTH_HOW_MASK) == AUTH_HOW_MUTUAL)
 	    {
-	      printf ("[ Kerberos V5 accepted you, but didn't provide mutual authentication! ]\r\n");
+	      printf
+		("[ Kerberos V5 accepted you, but didn't provide mutual authentication! ]\r\n");
 	      auth_send_retry ();
 	      break;
 	    }
@@ -369,15 +367,14 @@ kerberos5_reply (TN_Authenticator *ap, unsigned char *data, int cnt)
       if (cnt)
 	printf ("[ Kerberos V5 accepts you as ``%.*s''%s ]\r\n", cnt, data,
 		mutual_complete ?
-		" (server authenticated)" : 
-		" (server NOT authenticated)");
+		" (server authenticated)" : " (server NOT authenticated)");
       else
 	printf ("[ Kerberos V5 accepts you ]\r\n");
-      auth_finished(ap, AUTH_USER);
-#ifdef  FORWARD
+      auth_finished (ap, AUTH_USER);
+# ifdef  FORWARD
       if (forward_flags & OPTS_FORWARD_CREDS)
 	kerberos5_forward (ap);
-#endif 
+# endif
       break;
 
     case KRB_RESPONSE:
@@ -388,7 +385,7 @@ kerberos5_reply (TN_Authenticator *ap, unsigned char *data, int cnt)
 	  krb5_error_code r;
 
 	  inbuf.length = cnt;
-	  inbuf.data = (char *)data;
+	  inbuf.data = (char *) data;
 
 	  if ((r = krb5_rd_rep (telnet_context, auth_context, &inbuf,
 				&reply)))
@@ -398,31 +395,32 @@ kerberos5_reply (TN_Authenticator *ap, unsigned char *data, int cnt)
 	      auth_send_retry ();
 	      break;
 	    }
-	  
+
 	  krb5_free_ap_rep_enc_part (telnet_context, reply);
 	  telnet_encrypt_key (&skey);
 	  mutual_complete = 1;
 	}
       break;
 
-#ifdef  FORWARD
+# ifdef  FORWARD
     case KRB_FORWARD_ACCEPT:
       printf ("[ Kerberos V5 accepted forwarded credentials ]\r\n");
       break;
-      
+
     case KRB_FORWARD_REJECT:
-      printf ("[ Kerberos V5 refuses forwarded credentials because %.*s ]\r\n",
-	      cnt, data);
+      printf
+	("[ Kerberos V5 refuses forwarded credentials because %.*s ]\r\n",
+	 cnt, data);
       break;
-#endif  /* FORWARD */
+# endif	/* FORWARD */
 
     default:
-      DEBUG(("Unknown Kerberos option %d\r\n", data[-1]));
+      DEBUG (("Unknown Kerberos option %d\r\n", data[-1]));
     }
 }
 
 int
-kerberos5_status (TN_Authenticator *ap, char *name, int level)
+kerberos5_status (TN_Authenticator * ap, char *name, int level)
 {
   if (level < AUTH_USER)
     return level;
@@ -434,12 +432,12 @@ kerberos5_status (TN_Authenticator *ap, char *name, int level)
       /* FIXME: Check buffer length */
       strcpy (name, UserNameRequested);
       return AUTH_VALID;
-    } 
+    }
   return AUTH_USER;
 }
 
 int
-kerberos5_is_auth (TN_Authenticator *ap, unsigned char *data, int cnt,
+kerberos5_is_auth (TN_Authenticator * ap, unsigned char *data, int cnt,
 		   char *errbuf, int errbuflen)
 {
   int r = 0;
@@ -449,12 +447,12 @@ kerberos5_is_auth (TN_Authenticator *ap, unsigned char *data, int cnt,
   krb5_data outbuf;
   krb5_keyblock *newkey = NULL;
   krb5_principal server;
-  
-#ifdef ENCRYPTION
+
+# ifdef ENCRYPTION
   Session_Key skey;
-#endif
-  
-  auth.data = (char *)data;
+# endif
+
+  auth.data = (char *) data;
   auth.length = cnt;
 
   if (!r && !auth_context)
@@ -462,27 +460,25 @@ kerberos5_is_auth (TN_Authenticator *ap, unsigned char *data, int cnt,
   if (!r)
     {
       krb5_rcache rcache;
-    
-      r = krb5_auth_con_getrcache (telnet_context, auth_context,
-				   &rcache);
+
+      r = krb5_auth_con_getrcache (telnet_context, auth_context, &rcache);
       if (!r && !rcache)
 	{
-	  r = krb5_sname_to_principal(telnet_context, 0, 0,
-				      KRB5_NT_SRV_HST, &server);
+	  r = krb5_sname_to_principal (telnet_context, 0, 0,
+				       KRB5_NT_SRV_HST, &server);
 	  if (!r)
 	    {
-	      r = krb5_get_server_rcache(telnet_context,
-					 krb5_princ_component (telnet_context,
-							       server, 0),
-					 &rcache);
+	      r = krb5_get_server_rcache (telnet_context,
+					  krb5_princ_component
+					  (telnet_context, server, 0),
+					  &rcache);
 	      krb5_free_principal (telnet_context, server);
 	    }
 	}
       if (!r)
-	r = krb5_auth_con_setrcache (telnet_context,
-				     auth_context, rcache);
+	r = krb5_auth_con_setrcache (telnet_context, auth_context, rcache);
     }
-  
+
   if (!r && telnet_srvtab)
     r = krb5_kt_resolve (telnet_context, telnet_srvtab, &keytabid);
   if (!r)
@@ -498,19 +494,19 @@ kerberos5_is_auth (TN_Authenticator *ap, unsigned char *data, int cnt,
   /* 256 bytes should be much larger than any reasonable
      first component of a service name especially since
      the default is of length 4. */
-  if (krb5_princ_component (telnet_context,ticket->server,0)->length < 256)
+  if (krb5_princ_component (telnet_context, ticket->server, 0)->length < 256)
     {
       char princ[256];
       strncpy (princ,
-	       krb5_princ_component (telnet_context, ticket->server,0)->data,
-	       krb5_princ_component (telnet_context, ticket->server,0)->length);
-      princ[krb5_princ_component (telnet_context,
-				  ticket->server,0)->length] = '\0';
+	       krb5_princ_component (telnet_context, ticket->server, 0)->data,
+	       krb5_princ_component (telnet_context, ticket->server,
+				     0)->length);
+      princ[krb5_princ_component (telnet_context, ticket->server, 0)->
+	    length] = '\0';
       if (strcmp ("host", princ))
 	{
-	  snprintf(errbuf, errbuflen,
-		   "incorrect service name: \"%s\" != \"host\"",
-		   princ);
+	  snprintf (errbuf, errbuflen,
+		    "incorrect service name: \"%s\" != \"host\"", princ);
 	  return 1;
 	}
     }
@@ -521,8 +517,7 @@ kerberos5_is_auth (TN_Authenticator *ap, unsigned char *data, int cnt,
     }
 
   r = krb5_auth_con_getauthenticator (telnet_context,
-				      auth_context,
-				      &authenticator);
+				      auth_context, &authenticator);
   if (r)
     {
       snprintf (errbuf, errbuflen,
@@ -531,16 +526,16 @@ kerberos5_is_auth (TN_Authenticator *ap, unsigned char *data, int cnt,
       return 1;
     }
 
-#ifdef AUTH_ENCRYPT_MASK
+# ifdef AUTH_ENCRYPT_MASK
   if ((ap->way & AUTH_ENCRYPT_MASK) == AUTH_ENCRYPT_ON
-      &&  !authenticator->checksum)
+      && !authenticator->checksum)
     {
       snprintf (errbuf, errbuflen,
 		"authenticator is missing required checksum");
       return 1;
     }
-#endif
-  
+# endif
+
   if (authenticator->checksum)
     {
       char type_check[2];
@@ -550,63 +545,58 @@ kerberos5_is_auth (TN_Authenticator *ap, unsigned char *data, int cnt,
       type_check[0] = ap->type;
       type_check[1] = ap->way;
 
-      r = krb5_auth_con_getkey (telnet_context, auth_context,
-				&key);
+      r = krb5_auth_con_getkey (telnet_context, auth_context, &key);
       if (r)
 	{
 	  snprintf (errbuf, errbuflen,
-		    "krb5_auth_con_getkey failed: %s",
-		    error_message (r));
+		    "krb5_auth_con_getkey failed: %s", error_message (r));
 	  return 1;
 	}
-      
+
       r = krb5_verify_checksum (telnet_context,
 				cksum->checksum_type, cksum,
-				&type_check, 2, key->contents,
-				key->length);
-      
+				&type_check, 2, key->contents, key->length);
+
       if (r)
 	{
-	  snprintf (errbuf, errbuflen, 
-		    "checksum verification failed: %s",
-		    error_message (r));
+	  snprintf (errbuf, errbuflen,
+		    "checksum verification failed: %s", error_message (r));
 	  return 1;
 	}
       krb5_free_keyblock (telnet_context, key);
     }
-  
+
   krb5_free_authenticator (telnet_context, authenticator);
   if ((ap->way & AUTH_HOW_MASK) == AUTH_HOW_MUTUAL)
     {
-      if ((r = krb5_mk_rep (telnet_context, auth_context,
-			    &outbuf)))
+      if ((r = krb5_mk_rep (telnet_context, auth_context, &outbuf)))
 	{
 	  snprintf (errbuf, errbuflen, "Make reply failed: %s",
-		    error_message(r));
+		    error_message (r));
 	  return 1;
 	}
 
       Data (ap, KRB_RESPONSE, outbuf.data, outbuf.length);
     }
-  
-  if (krb5_unparse_name (telnet_context, ticket->enc_part2 ->client, &name))
+
+  if (krb5_unparse_name (telnet_context, ticket->enc_part2->client, &name))
     name = 0;
-  
+
   Data (ap, KRB_ACCEPT, name, name ? -1 : 0);
-  DEBUG(("telnetd: Kerberos5 identifies him as ``%s''\r\n",
-	 name ? name : ""));
+  DEBUG (("telnetd: Kerberos5 identifies him as ``%s''\r\n",
+	  name ? name : ""));
   auth_finished (ap, AUTH_USER);
 
   if (name)
     free (name);
   krb5_auth_con_getremotesubkey (telnet_context, auth_context, &newkey);
-  
+
   if (session_key)
     {
       krb5_free_keyblock (telnet_context, session_key);
       session_key = 0;
     }
-  
+
   if (newkey)
     {
       krb5_copy_keyblock (telnet_context, newkey, &session_key);
@@ -621,44 +611,44 @@ kerberos5_is_auth (TN_Authenticator *ap, unsigned char *data, int cnt,
   return 0;
 }
 
-#ifdef FORWARD
+# ifdef FORWARD
 int
-kerberos5_is_forward (TN_Authenticator *ap, unsigned char *data, int cnt,
+kerberos5_is_forward (TN_Authenticator * ap, unsigned char *data, int cnt,
 		      char *errbuf, int errbuflen)
 {
   int r = 0;
   krb5_data inbuf;
-  
+
   inbuf.length = cnt;
-  inbuf.data = (char *)data;
+  inbuf.data = (char *) data;
   if ((r = krb5_auth_con_genaddrs (telnet_context, auth_context,
 				   net,
 				   KRB5_AUTH_CONTEXT_GENERATE_REMOTE_FULL_ADDR))
-      || (r = rd_and_store_for_creds(telnet_context, auth_context,
-				     &inbuf, ticket)))
+      || (r = rd_and_store_for_creds (telnet_context, auth_context,
+				      &inbuf, ticket)))
     {
       snprintf (errbuf, errbuflen, "Read forwarded creds failed: %s",
 		error_message (r));
       Data (ap, KRB_FORWARD_REJECT, errbuf, -1);
-      DEBUG(("Could not read forwarded credentials\r\n"));
+      DEBUG (("Could not read forwarded credentials\r\n"));
     }
   else
     {
-      Data(ap, KRB_FORWARD_ACCEPT, 0, 0);
-      DEBUG(("Forwarded credentials obtained\r\n"));
+      Data (ap, KRB_FORWARD_ACCEPT, 0, 0);
+      DEBUG (("Forwarded credentials obtained\r\n"));
     }
   return r;
 }
-#else
-# define kerberos5_is_forward(ap,data,cnt,errbuf,errbuflen) 0
-#endif
-     
+# else
+#  define kerberos5_is_forward(ap,data,cnt,errbuf,errbuflen) 0
+# endif
+
 void
-kerberos5_is (TN_Authenticator *ap, unsigned char *data, int cnt)
+kerberos5_is (TN_Authenticator * ap, unsigned char *data, int cnt)
 {
   int r = 0;
   char errbuf[512];
-    
+
   if (cnt-- < 1)
     return;
   errbuf[0] = 0;
@@ -673,9 +663,8 @@ kerberos5_is (TN_Authenticator *ap, unsigned char *data, int cnt)
       break;
 
     default:
-      DEBUG(("Unknown Kerberos option %d\r\n",
-	     data[-1]));
-      Data(ap, KRB_REJECT, 0, 0);
+      DEBUG (("Unknown Kerberos option %d\r\n", data[-1]));
+      Data (ap, KRB_REJECT, 0, 0);
       break;
     }
 
@@ -683,9 +672,9 @@ kerberos5_is (TN_Authenticator *ap, unsigned char *data, int cnt)
     {
       if (!errbuf[0])
 	snprintf (errbuf, sizeof errbuf,
-		  "kerberos_is: %s", error_message(r));
+		  "kerberos_is: %s", error_message (r));
       Data (ap, KRB_REJECT, errbuf, -1);
-      DEBUG(("%s\r\n", errbuf));
+      DEBUG (("%s\r\n", errbuf));
       syslog (LOG_ERR, "%s", errbuf);
       if (auth_context)
 	{
@@ -694,7 +683,7 @@ kerberos5_is (TN_Authenticator *ap, unsigned char *data, int cnt)
 	}
     }
 }
-    
+
 static char *
 req_type_str (int type)
 {
@@ -702,7 +691,7 @@ req_type_str (int type)
     {
     case KRB_REJECT:
       return "REJECT";
-      
+
     case KRB_ACCEPT:
       return "ACCEPT";
 
@@ -724,17 +713,17 @@ req_type_str (int type)
     }
   return NULL;
 }
-     
-#define ADDC(p,l,c) if ((l) > 0) {*(p)++ = (c); --(l);}
+
+# define ADDC(p,l,c) if ((l) > 0) {*(p)++ = (c); --(l);}
 
 void
 kerberos5_printsub (unsigned char *data, int cnt,
-		    unsigned char *buf,  int buflen)
+		    unsigned char *buf, int buflen)
 {
   char *p;
   int i;
 
-  buf[buflen-1] = '\0';           /* make sure its NULL terminated */
+  buf[buflen - 1] = '\0';	/* make sure its NULL terminated */
   buflen -= 1;
 
   p = req_type_str (data[3]);
@@ -749,18 +738,18 @@ kerberos5_printsub (unsigned char *data, int cnt,
       while (buflen > 0 && (*buf++ = *p++) != 0)
 	buflen--;
     }
-      
+
   switch (data[3])
     {
-    case KRB_REJECT:  /* Rejected (reason might follow) */
-    case KRB_ACCEPT:  /* Accepted (username might follow) */
+    case KRB_REJECT:		/* Rejected (reason might follow) */
+    case KRB_ACCEPT:		/* Accepted (username might follow) */
       if (cnt <= 4)
 	break;
-      ADDC(buf, buflen, '"');
+      ADDC (buf, buflen, '"');
       for (i = 4; i < cnt; i++)
-	ADDC(buf, buflen, data[i]);
-      ADDC(buf, buflen, '"');
-      ADDC(buf, buflen, '\0');
+	ADDC (buf, buflen, data[i]);
+      ADDC (buf, buflen, '"');
+      ADDC (buf, buflen, '\0');
       break;
 
     case KRB_AUTH:
@@ -773,14 +762,14 @@ kerberos5_printsub (unsigned char *data, int cnt,
 	  int l = snprintf (buf, buflen, " %d", data[i]);
 	  buf += l;
 	  buflen -= l;
-      }
+	}
     }
 }
-     
-#ifdef FORWARD
+
+# ifdef FORWARD
 
 void
-kerberos5_forward (TN_Authenticator *ap)
+kerberos5_forward (TN_Authenticator * ap)
 {
   krb5_error_code r;
   krb5_ccache ccache;
@@ -792,31 +781,32 @@ kerberos5_forward (TN_Authenticator *ap)
 
   if ((r = krb5_cc_default (telnet_context, &ccache)))
     {
-      DEBUG(("Kerberos V5: could not get default ccache - %s\r\n",
-	     error_message(r)));
+      DEBUG (("Kerberos V5: could not get default ccache - %s\r\n",
+	      error_message (r)));
       return;
     }
 
-  for (;;) /* Fake loop */
+  for (;;)			/* Fake loop */
     {
       if ((r = krb5_cc_get_principal (telnet_context, ccache, &client)))
 	{
-	  DEBUG(("Kerberos V5: could not get default principal - %s\r\n",
-		 error_message(r)));
+	  DEBUG (("Kerberos V5: could not get default principal - %s\r\n",
+		  error_message (r)));
 	  break;
 	}
-      if ((r = krb5_sname_to_principal (telnet_context, RemoteHostName, "host",
-				       KRB5_NT_SRV_HST, &server)))
+      if ((r =
+	   krb5_sname_to_principal (telnet_context, RemoteHostName, "host",
+				    KRB5_NT_SRV_HST, &server)))
 	{
-	  DEBUG(("Kerberos V5: could not make server principal - %s\r\n",
-		 error_message(r)));
+	  DEBUG (("Kerberos V5: could not make server principal - %s\r\n",
+		  error_message (r)));
 	  break;
 	}
       if ((r = krb5_auth_con_genaddrs (telnet_context, auth_context, net,
-			       KRB5_AUTH_CONTEXT_GENERATE_LOCAL_FULL_ADDR)))
+				       KRB5_AUTH_CONTEXT_GENERATE_LOCAL_FULL_ADDR)))
 	{
-	  DEBUG(("Kerberos V5: could not gen local full address - %s\r\n",
-		 error_message(r)));
+	  DEBUG (("Kerberos V5: could not gen local full address - %s\r\n",
+		  error_message (r)));
 	  break;
 	}
       if ((r = krb5_fwd_tgt_creds (telnet_context, auth_context, 0, client,
@@ -824,31 +814,31 @@ kerberos5_forward (TN_Authenticator *ap)
 				   forward_flags & OPTS_FORWARDABLE_CREDS,
 				   &forw_creds)))
 	{
-	  DEBUG(("Kerberos V5: error getting forwarded creds - %s\r\n",
-		 error_message(r)));
+	  DEBUG (("Kerberos V5: error getting forwarded creds - %s\r\n",
+		  error_message (r)));
 	  break;
 	}
 
       /* Send forwarded credentials */
-      if (!Data(ap, KRB_FORWARD, forw_creds.data, forw_creds.length))
+      if (!Data (ap, KRB_FORWARD, forw_creds.data, forw_creds.length))
 	{
-	  DEBUG(("Not enough room for authentication data\r\n"));
+	  DEBUG (("Not enough room for authentication data\r\n"));
 	}
       else
 	{
-	  DEBUG(("Forwarded local Kerberos V5 credentials to server\r\n"));
+	  DEBUG (("Forwarded local Kerberos V5 credentials to server\r\n"));
 	}
       break;
     }
-  
+
   if (client)
-    krb5_free_principal(telnet_context, client);
+    krb5_free_principal (telnet_context, client);
   if (server)
-    krb5_free_principal(telnet_context, server);
+    krb5_free_principal (telnet_context, server);
   if (forw_creds.data)
-    free(forw_creds.data);
-  krb5_cc_close(telnet_context, ccache);
+    free (forw_creds.data);
+  krb5_cc_close (telnet_context, ccache);
 }
-#endif  
-      
+# endif
+
 #endif /* KRB5 */
