@@ -1,4 +1,5 @@
-/* Copyright (C) 1998, 2001, 2002, 2004, 2005, 2007 Free Software Foundation, Inc.
+/* Copyright (C) 1998, 2001, 2002, 2004, 2005, 2006, 2007, 2008
+   Free Software Foundation, Inc.
 
    This file is part of GNU Inetutils.
 
@@ -34,173 +35,181 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#include <argp.h>
 #include <ctype.h>
 #include <errno.h>
 #include <limits.h>
 
-#include <getopt.h>
 #include <xalloc.h>
-#include "ping_common.h"
 #include "ping6.h"
-
-static char short_options[] = "VLhc:dfi:l:np:qRrs:t:v";
-static struct option long_options[] = 
-{
-  /* Help options */
-  {"version", no_argument, NULL, 'V'},
-  {"license", no_argument, NULL, 'L'},
-  {"help",    no_argument, NULL, 'h'},
-  /* Common options */
-  {"count",   required_argument, NULL, 'c'},
-  {"debug",   no_argument, NULL, 'd'},
-  {"ignore-routing", no_argument, NULL, 'r'},
-  {"size",    required_argument, NULL, 's'},
-  {"interval",required_argument, NULL, 'i'},
-  {"numeric", no_argument, NULL, 'n'},
-  /* echo-specific options */
-  {"flood",   no_argument, NULL, 'f'},
-  {"preload", required_argument, NULL, 'l'},
-  {"pattern", required_argument, NULL, 'p'},
-  {"quiet",   no_argument, NULL, 'q'},
-  {NULL,      no_argument, NULL, 0}
-};
+#include "libinetutils.h"
 
 static PING *ping;
+bool is_root = false;
 unsigned char *data_buffer;
+u_char *patptr;
+int one = 1;
+int pattern_len = 16;
 size_t data_length = PING_DATALEN;
+size_t count = DEFAULT_PING_COUNT;
+size_t interval;
+int socket_type;
 static unsigned int options;
 static unsigned long preload = 0;
 
-static int ping_echo (int argc, char **argv);
+static int ping_echo (char *hostname);
+static void ping_reset (PING * p);
+static int send_echo (PING * ping);
 
-static void show_usage (void);
-static int send_echo (PING *ping);
+ARGP_PROGRAM_DATA ("ping6", "2007", "Jeroen Dekkers");
 
-char *program_name;
+const char args_doc[] = "HOST ...";
+const char doc[] = "Send ICMP ECHO_REQUEST packets to network hosts."
+                   "\vOptions marked with (root only) are available only to "
+                   "superuser.";
+
+static struct argp_option argp_options[] = {
+#define GRP 0
+  {NULL, 0, NULL, 0, "Options valid for all request types:", GRP},
+  {"count", 'c', "NUMBER", 0, "Stop after sending NUMBER packets", GRP+1},
+  {"debug", 'd', NULL, 0, "Set the SO_DEBUG option", GRP+1},
+  {"interval", 'i', "NUMBER", 0, "Wait NUMBER seconds between sending each "
+   "packet", GRP+1},
+  {"numeric", 'n', NULL, 0, "Do not resolve host addresses", GRP+1},
+  {"ignore-routing", 'r', NULL, 0, "Send directly to a host on an attached "
+   "network", GRP+1},
+#undef GRP
+#define GRP 10
+  {NULL, 0, NULL, 0, "Options valid for --echo requests:", GRP},
+  {"flood", 'f', NULL, 0, "Flood ping (root only)", GRP+1},
+  {"preload", 'l', "NUMBER", 0, "Send NUMBER packets as fast as possible "
+   "before falling into normal mode of behavior (root only)", GRP+1},
+  {"pattern", 'p', "PATTERN", 0, "Fill ICMP packet with given pattern (hex)",
+   GRP+1},
+  {"quiet", 'q', NULL, 0, "Quiet output", GRP+1},
+  {"size", 's', "NUMBER", 0, "Send NUMBER data octets", GRP+1},
+#undef GRP
+  {NULL}
+};
+
+static error_t
+parse_opt (int key, char *arg, struct argp_state *state)
+{
+  char *endptr;
+  u_char pattern[16];
+  double v;
+
+  switch (key)
+    {
+    case 'c':
+      count = ping_cvt_number (arg, 0, 0);
+      break;
+
+    case 'd':
+      socket_type = SO_DEBUG;
+      break;
+
+    case 'f':
+      if (!is_root)
+        error (EXIT_FAILURE, errno, NULL);
+
+      options |= OPT_FLOOD;
+      setbuf (stdout, (char *) NULL);
+      break;
+
+    case 'i':
+      options |= OPT_INTERVAL;
+      interval = ping_cvt_number (arg, 0, 0);
+      break;
+
+    case 'l':
+      if (!is_root)
+        error (EXIT_FAILURE, errno, NULL);
+
+      preload = strtoul (arg, &endptr, 0);
+      if (*endptr || preload > INT_MAX)
+        error (EXIT_FAILURE, errno, NULL);
+
+      break;
+
+    case 'n':
+      options |= OPT_NUMERIC;
+      break;
+
+    case 'p':
+      decode_pattern (arg, &pattern_len, pattern);
+      patptr = pattern;
+      break;
+
+    case 'q':
+      options |= OPT_QUIET;
+      break;
+
+    case 'r':
+      socket_type = SO_DEBUG;
+      break;
+
+    case 's':
+      data_length = ping_cvt_number (arg, PING_MAX_DATALEN, 1);
+      break;
+
+    case ARGP_KEY_NO_ARGS:
+      argp_error (state, "missing host operand");
+
+    default:
+      return ARGP_ERR_UNKNOWN;
+    }
+
+  return 0;
+}
+
+static struct argp argp = {argp_options, parse_opt, args_doc, doc};
 
 int
 main (int argc, char **argv)
 {
-  int c;
-  char *p;
-  int one = 1;
-  u_char pattern[16];
-  int pattern_len = 16;
-  u_char *patptr = NULL;
-  int is_root = getuid () == 0;
+  int index;
+  int status = 0;
 
-  program_name = argv[0];
-  if ((ping = ping_init (0, getpid ())) == NULL)
-    {
-      fprintf (stderr, "can't init ping: %s\n", strerror (errno));
-      exit (1);
-    }
-  setsockopt (ping->ping_fd, SOL_SOCKET, SO_BROADCAST, (char *)&one, sizeof (one));
+  set_program_name (argv[0]);
+  
+  if (getuid () == 0)
+    is_root = true;
+
+  /* Parse command line */
+  argp_parse (&argp, argc, argv, 0, &index, NULL);
+
+  ping = ping_init (0, getpid ());
+  if (ping == NULL)
+    /* ping_init() prints our error message.  */
+    exit (1);
+
+  setsockopt (ping->ping_fd, SOL_SOCKET, SO_BROADCAST, (char *) &one, sizeof (one));
 
   /* Reset root privileges */
   setuid (getuid ());
 
-  /* Parse command line */
-  while ((c = getopt_long (argc, argv, short_options, long_options, NULL))
-	 != EOF)
-    {
-      switch (c)
-	{
-	case 'V':
-	  printf ("ping - %s %s\n", PACKAGE_NAME, PACKAGE_VERSION);
-	  printf ("Copyright (C) 2005 Free Software Foundation, Inc.\n");
-	  printf ("%s comes with ABSOLUTELY NO WARRANTY.\n", PACKAGE_NAME);
-	  printf ("You may redistribute copies of %s\n", PACKAGE_NAME);
-	  printf ("under the terms of the GNU General Public License.\n");
-	  printf ("For more information about these matters, ");
-	  printf ("see the files named COPYING.\n");
-	  exit (0);
-	  break;
-	  
-	case 'L':
-	  show_license ();
-	  exit (0);
-	  
-	case 'h':
-	  show_usage ();
-	  exit (0);
-	  break;
-	  
-	case 'c':
-	  ping->ping_count = ping_cvt_number (optarg, 0, 0);
-	  break;
-	  
-	case 'd':
-	  setsockopt (ping->ping_fd, SOL_SOCKET, SO_DEBUG, &one, sizeof (one));
-	  break;
-	  
-	case 'r':
-	  setsockopt (ping->ping_fd, SOL_SOCKET, SO_DONTROUTE, &one, sizeof (one));
-	  break;
-	  
-	case 'i':
-	  options |= OPT_INTERVAL;
-	  ping->ping_interval = ping_cvt_number (optarg, 0, 0);
-	  break;
-	  
-	case 'p':
-	  decode_pattern (optarg, &pattern_len, pattern);
-	  patptr = pattern;
-	  break;
-	  
- 	case 's':
-	  data_length = ping_cvt_number (optarg, PING_MAX_DATALEN, 1);
- 	  break;
-	  
-	case 'n':
-	  options |= OPT_NUMERIC;
-	  break;
-	  
-	case 'q':
-	  options |= OPT_QUIET;
-	  break;
-	  
-	case 'l':
-	  if (!is_root)
-	    {
-	      fprintf (stderr, "ping: option not allowed: --preload\n");
-	      exit (1);
-	    }
-	  preload = strtoul (optarg, &p, 0);
-	  if (*p || preload > INT_MAX)
-	    {
-	      fprintf (stderr, "ping: invalid preload value (%s)\n", optarg);
-	      exit (1);
-	    }
-	  break;
+  argc -= index;
+  argv += index;
 
-	case 'f':
-	  if (!is_root)
-	    {
-	      fprintf (stderr, "ping: option not allowed: --flood\n");
-	      exit (1);
-	    }
-	  options |= OPT_FLOOD;
-	  setbuf (stdout, (char *)NULL);
-	  break;
+  if (count != 0)
+    ping_set_count (ping, count);
 
-	default:
-	  fprintf (stderr, "%c: not implemented\n", c);
-	  exit (1);
-	}
-    }
+  if (socket_type != 0)
+    ping_set_sockopt (ping, socket_type, &one, sizeof (one));
 
-  argc -= optind;
-  argv += optind;
-  if (argc == 0) 
-    {
-      show_usage ();
-      exit (0);
-    }
+  if (options & OPT_INTERVAL)
+    ping_set_interval (ping, interval);
 
   init_data_buffer (patptr, pattern_len);
 
-  return ping_echo (argc, argv);
+  while (argc--)
+    {
+      status |= ping_echo (*argv++);
+      ping_reset (ping);
+    }
+
+  return status;
 }
 
 static char *
@@ -215,16 +224,16 @@ ipaddr2str (struct sockaddr_in6 *from)
   if (err)
     {
       const char *errmsg;
-      
+
       if (err == EAI_SYSTEM)
 	errmsg = strerror (errno);
       else
 	errmsg = gai_strerror (err);
-      
+
       fprintf (stderr, "ping: getnameinfo: %s\n", errmsg);
       return xstrdup ("unknown");
     }
-  
+
   if (options & OPT_NUMERIC)
     return xstrdup (ipstr);
 
@@ -233,8 +242,8 @@ ipaddr2str (struct sockaddr_in6 *from)
   if (err)
     return xstrdup (ipstr);
 
-  len = strlen (ipstr) + strlen (hoststr) + 4; /* Pair of parentheses, a space
-						  and a NUL. */
+  len = strlen (ipstr) + strlen (hoststr) + 4;	/* Pair of parentheses, a space
+						   and a NUL. */
   buf = xmalloc (len);
   sprintf (buf, "%s (%s)", hoststr, ipstr);
 
@@ -250,7 +259,7 @@ sig_int (int signal)
 }
 
 static int
-ping_run (PING *ping, int (*finish)())
+ping_run (PING * ping, int (*finish) ())
 {
   fd_set fdset;
   int fdmax;
@@ -259,12 +268,13 @@ ping_run (PING *ping, int (*finish)())
   struct timeval *t = NULL;
   int finishing = 0;
   int nresp = 0;
+  int i;
 
   signal (SIGINT, sig_int);
-  
-  fdmax = ping->ping_fd+1;
 
-  while (preload--)      
+  fdmax = ping->ping_fd + 1;
+
+  for (i = 0; i < preload; i++)
     send_echo (ping);
 
   if (options & OPT_FLOOD)
@@ -273,18 +283,15 @@ ping_run (PING *ping, int (*finish)())
       intvl.tv_usec = 10000;
     }
   else
-    {
-      intvl.tv_sec = ping->ping_interval;
-      intvl.tv_usec = 0;
-    }
-  
+    PING_SET_INTERVAL (intvl, ping->ping_interval);
+
   gettimeofday (&last, NULL);
   send_echo (ping);
 
   while (!stop)
     {
       int n;
-      
+
       FD_ZERO (&fdset);
       FD_SET (ping->ping_fd, &fdset);
       gettimeofday (&now, NULL);
@@ -337,7 +344,7 @@ ping_run (PING *ping, int (*finish)())
 	  else if (finishing)
 	    break;
 	  else
- 	    {
+	    {
 	      finishing = 1;
 
 	      intvl.tv_sec = MAXWAIT;
@@ -345,27 +352,30 @@ ping_run (PING *ping, int (*finish)())
 	  gettimeofday (&last, NULL);
 	}
     }
+
+  ping_unset_data (ping);
+
   if (finish)
-    return (*finish)();
+    return (*finish) ();
   return 0;
 }
 
 static int
-send_echo (PING *ping)
+send_echo (PING * ping)
 {
   int off = 0;
-  
+
   if (PING_TIMING (data_length))
     {
       struct timeval tv;
       gettimeofday (&tv, NULL);
-      ping_set_data (ping, &tv, 0, sizeof (tv));
+      ping_set_data (ping, &tv, 0, sizeof (tv), USE_IPV6);
       off += sizeof (tv);
     }
   if (data_buffer)
     ping_set_data (ping, data_buffer, off,
 		   data_length > PING_HEADER_LEN ?
-		   data_length - PING_HEADER_LEN : data_length);
+		   data_length - PING_HEADER_LEN : data_length, USE_IPV6);
   return ping_xmit (ping);
 }
 
@@ -377,15 +387,15 @@ ping_finish ()
   printf ("%ld packets transmitted, ", ping->ping_num_xmit);
   printf ("%ld packets received, ", ping->ping_num_recv);
   if (ping->ping_num_rept)
-    printf ("+%ld duplicates, ", ping->ping_num_rept);  
+    printf ("+%ld duplicates, ", ping->ping_num_rept);
   if (ping->ping_num_xmit)
     {
       if (ping->ping_num_recv > ping->ping_num_xmit)
 	printf ("-- somebody's printing up packets!");
       else
 	printf ("%d%% packet loss",
-	       (int) (((ping->ping_num_xmit - ping->ping_num_recv) * 100) /
-		      ping->ping_num_xmit));
+		(int) (((ping->ping_num_xmit - ping->ping_num_recv) * 100) /
+		       ping->ping_num_xmit));
 
     }
   printf ("\n");
@@ -401,52 +411,54 @@ static void print_icmp_error (struct sockaddr_in6 *from,
 static int echo_finish (void);
 
 static int
-ping_echo (int argc, char **argv)
+ping_echo (char *hostname)
 {
   int err;
   char buffer[256];
   struct ping_stat ping_stat;
+  int status;
 
   if (options & OPT_FLOOD && options & OPT_INTERVAL)
-    {
-      fprintf (stderr,
-	       "ping: -f and -i incompatible options.\n");
-      return 2;
-    }
+    error (EXIT_FAILURE, 0, "-f and -i incompatible options");
 
   memset (&ping_stat, 0, sizeof (ping_stat));
   ping_stat.tmin = 999999999.0;
 
   ping->ping_datalen = data_length;
   ping->ping_closure = &ping_stat;
-  
-  if (ping_set_dest (ping, *argv))
-    {
-      fprintf (stderr, "ping: unknown host\n");
-      exit (1);
-    }
 
-  err = getnameinfo ((struct sockaddr *) &ping->ping_dest,
-		     sizeof (ping->ping_dest), buffer,
+  if (ping_set_dest (ping, hostname))
+    error (EXIT_FAILURE, 0, "unknown host %s", hostname);
+
+  err = getnameinfo ((struct sockaddr *) &ping->ping_dest.ping_sockaddr6,
+		     sizeof (ping->ping_dest.ping_sockaddr6), buffer,
 		     sizeof (buffer), NULL, 0, NI_NUMERICHOST);
   if (err)
     {
       const char *errmsg;
-      
+
       if (err == EAI_SYSTEM)
 	errmsg = strerror (errno);
       else
 	errmsg = gai_strerror (err);
 
-      fprintf (stderr, "ping: getnameinfo: %s\n", errmsg);
-
-      exit (1);
+      error (EXIT_FAILURE, 0, "getnameinfo: %s", errmsg);
     }
-  
+
   printf ("PING %s (%s): %d data bytes\n",
 	  ping->ping_hostname, buffer, data_length);
 
-  return ping_run (ping, echo_finish);
+  status = ping_run (ping, echo_finish);
+  free (ping->ping_hostname);
+  return status;
+}
+
+static void
+ping_reset (PING * p)
+{
+  p->ping_num_xmit = 0;
+  p->ping_num_recv = 0;
+  p->ping_num_rept = 0;
 }
 
 static int
@@ -468,16 +480,16 @@ print_echo (int dupflag, int hops, struct ping_stat *ping_stat,
       struct timeval tv1, *tp;
 
       timing++;
-      tp = (struct timeval *) icmp6 + 1;
+      tp = (struct timeval *) (icmp6 + 1);
 
       /* Avoid unaligned data: */
       memcpy (&tv1, tp, sizeof (tv1));
       tvsub (&tv, &tv1);
 
-      triptime = ((double)tv.tv_sec) * 1000.0 +
-	          ((double)tv.tv_usec) / 1000.0;
+      triptime = ((double) tv.tv_sec) * 1000.0 +
+	((double) tv.tv_usec) / 1000.0;
       ping_stat->tsum += triptime;
-      ping_stat->tsumsq += triptime*triptime;
+      ping_stat->tsumsq += triptime * triptime;
       if (triptime < ping_stat->tmin)
 	ping_stat->tmin = triptime;
       if (triptime > ping_stat->tmax)
@@ -497,7 +509,7 @@ print_echo (int dupflag, int hops, struct ping_stat *ping_stat,
   if (err)
     {
       const char *errmsg;
-      
+
       if (err == EAI_SYSTEM)
 	errmsg = strerror (errno);
       else
@@ -508,7 +520,8 @@ print_echo (int dupflag, int hops, struct ping_stat *ping_stat,
       strcpy (buf, "unknown");
     }
 
-  printf ("%d bytes from %s: icmp_seq=%u", datalen, buf, htons (icmp6->icmp6_seq));
+  printf ("%d bytes from %s: icmp_seq=%u", datalen, buf,
+	  htons (icmp6->icmp6_seq));
   if (hops >= 0)
     printf (" ttl=%d", hops);
   if (timing)
@@ -523,17 +536,18 @@ print_echo (int dupflag, int hops, struct ping_stat *ping_stat,
 
 #define NITEMS(a) sizeof(a)/sizeof((a)[0])
 
-struct icmp_code_descr {
+struct icmp_code_descr
+{
   int code;
   char *diag;
 };
 
 static struct icmp_code_descr icmp_dest_unreach_desc[] = {
-  { ICMP6_DST_UNREACH_NOROUTE, "No route to destination" },
-  { ICMP6_DST_UNREACH_ADMIN, "Destination administratively prohibited" },
-  { ICMP6_DST_UNREACH_BEYONDSCOPE, "Beyond scope of source address"  },
-  { ICMP6_DST_UNREACH_ADDR, "Address unreachable" },
-  { ICMP6_DST_UNREACH_NOPORT, "Port unreachable" },
+  {ICMP6_DST_UNREACH_NOROUTE, "No route to destination"},
+  {ICMP6_DST_UNREACH_ADMIN, "Destination administratively prohibited"},
+  {ICMP6_DST_UNREACH_BEYONDSCOPE, "Beyond scope of source address"},
+  {ICMP6_DST_UNREACH_ADDR, "Address unreachable"},
+  {ICMP6_DST_UNREACH_NOPORT, "Port unreachable"},
 };
 
 static void
@@ -543,8 +557,7 @@ print_dst_unreach (struct icmp6_hdr *icmp6)
 
   printf ("Destination unreachable: ");
   for (p = icmp_dest_unreach_desc;
-       p < icmp_dest_unreach_desc + NITEMS(icmp_dest_unreach_desc);
-       p++)
+       p < icmp_dest_unreach_desc + NITEMS (icmp_dest_unreach_desc); p++)
     {
       if (p->code == icmp6->icmp6_code)
 	{
@@ -563,8 +576,8 @@ print_packet_too_big (struct icmp6_hdr *icmp6)
 }
 
 static struct icmp_code_descr icmp_time_exceeded_desc[] = {
-  { ICMP6_TIME_EXCEED_TRANSIT, "Hop limit exceeded"},
-  { ICMP6_TIME_EXCEED_REASSEMBLY, "Fragment reassembly timeout"},
+  {ICMP6_TIME_EXCEED_TRANSIT, "Hop limit exceeded"},
+  {ICMP6_TIME_EXCEED_REASSEMBLY, "Fragment reassembly timeout"},
 };
 
 static void
@@ -574,8 +587,7 @@ print_time_exceeded (struct icmp6_hdr *icmp6)
 
   printf ("Time exceeded: ");
   for (p = icmp_time_exceeded_desc;
-       p < icmp_time_exceeded_desc + NITEMS(icmp_time_exceeded_desc);
-       p++)
+       p < icmp_time_exceeded_desc + NITEMS (icmp_time_exceeded_desc); p++)
     {
       if (p->code == icmp6->icmp6_code)
 	{
@@ -588,9 +600,9 @@ print_time_exceeded (struct icmp6_hdr *icmp6)
 }
 
 static struct icmp_code_descr icmp_param_prob_desc[] = {
-  { ICMP6_PARAMPROB_HEADER, "Erroneous header field"},
-  { ICMP6_PARAMPROB_NEXTHEADER, "Unrecognized Next Header type"},
-  { ICMP6_PARAMPROB_OPTION, "Unrecognized IPv6 option"},
+  {ICMP6_PARAMPROB_HEADER, "Erroneous header field"},
+  {ICMP6_PARAMPROB_NEXTHEADER, "Unrecognized Next Header type"},
+  {ICMP6_PARAMPROB_OPTION, "Unrecognized IPv6 option"},
 };
 
 static void
@@ -600,8 +612,7 @@ print_param_prob (struct icmp6_hdr *icmp6)
 
   printf ("Parameter problem: ");
   for (p = icmp_param_prob_desc;
-       p < icmp_param_prob_desc + NITEMS(icmp_param_prob_desc);
-       p++)
+       p < icmp_param_prob_desc + NITEMS (icmp_param_prob_desc); p++)
     {
       if (p->code == icmp6->icmp6_code)
 	{
@@ -613,28 +624,32 @@ print_param_prob (struct icmp6_hdr *icmp6)
   printf ("Unknown code %d\n", icmp6->icmp6_code);
 }
 
-static struct icmp_diag {
+static struct icmp_diag
+{
   int type;
   void (*func) (struct icmp6_hdr *);
-} icmp_diag[] = {
-  { ICMP6_DST_UNREACH, print_dst_unreach },
-  { ICMP6_PACKET_TOO_BIG, print_packet_too_big },
-  { ICMP6_TIME_EXCEEDED, print_time_exceeded },
-  { ICMP6_PARAM_PROB, print_param_prob },
-};
+} icmp_diag[] =
+{
+  {
+  ICMP6_DST_UNREACH, print_dst_unreach},
+  {
+  ICMP6_PACKET_TOO_BIG, print_packet_too_big},
+  {
+  ICMP6_TIME_EXCEEDED, print_time_exceeded},
+  {
+ICMP6_PARAM_PROB, print_param_prob},};
 
 static void
-print_icmp_error (struct sockaddr_in6 *from,
-		  struct icmp6_hdr *icmp6, int len)
+print_icmp_error (struct sockaddr_in6 *from, struct icmp6_hdr *icmp6, int len)
 {
   char *s;
   struct icmp_diag *p;
-  
+
   s = ipaddr2str (from);
   printf ("%d bytes from %s: ", len, s);
   free (s);
 
-  for (p = icmp_diag; p < icmp_diag + NITEMS(icmp_diag); p++)
+  for (p = icmp_diag; p < icmp_diag + NITEMS (icmp_diag); p++)
     {
       if (p->type == icmp6->icmp6_type)
 	{
@@ -654,45 +669,15 @@ echo_finish ()
   ping_finish ();
   if (ping->ping_num_recv && PING_TIMING (data_length))
     {
-      struct ping_stat *ping_stat = (struct ping_stat*)ping->ping_closure;
+      struct ping_stat *ping_stat = (struct ping_stat *) ping->ping_closure;
       double total = ping->ping_num_recv + ping->ping_num_rept;
-      double avg = ping_stat->tsum/total;
+      double avg = ping_stat->tsum / total;
       double vari = ping_stat->tsumsq / total - avg * avg;
 
       printf ("round-trip min/avg/max/stddev = %.3f/%.3f/%.3f/%.3f ms\n",
 	      ping_stat->tmin, avg, ping_stat->tmax, nsqrt (vari, 0.0005));
     }
-  exit (ping->ping_num_recv == 0);
-}
-
-static void
-show_usage (void)
-{
-  printf ("\
-Usage: ping6 [OPTION]... [ADDRESS]...\n\
-\n\
-Informational options:\n\
-  -h, --help         display this help and exit\n\
-  -L, --license      display license and exit\n\
-  -V, --version      output version information and exit\n\
-Options valid for all request types:\n\
-  -c, --count N      stop after sending N packets\n\
-  -d, --debug        set the SO_DEBUG option\n\
-  -i, --interval N   wait N seconds between sending each packet\n\
-  -n, --numeric      do not resolve host addresses\n\
-  -r, --ignore-routing  send directly to a host on an attached network\n\
-Options valid for --echo requests:\n\
-* -f, --flood        flood ping \n\
-* -l, --preload N    send N packets as fast as possible before falling into\n\
-                     normal mode of behavior\n\
-  -p, --pattern PAT  fill ICMP packet with given pattern (hex)\n\
-  -q, --quiet        quiet output\n\
-  -s, --size N       set number of data octets to send\n\
-\n\
-Options marked with an * are available only to super-user\n\
-\n\
-report bugs to " PACKAGE_BUGREPORT ".\n\
-");
+  return (ping->ping_num_recv == 0);
 }
 
 static PING *
@@ -705,12 +690,11 @@ ping_init (int type, int ident)
 
   /* Initialize raw ICMPv6 socket */
   fd = socket (PF_INET6, SOCK_RAW, IPPROTO_ICMPV6);
-  if (fd < 0) 
+  if (fd < 0)
     {
-      if (errno == EPERM) 
-	{
-	  fprintf (stderr, "ping: ping must run as root\n");
-	}
+      if (errno == EPERM)
+        error (EXIT_FAILURE, errno, NULL);
+
       return NULL;
     }
 
@@ -722,7 +706,8 @@ ping_init (int type, int ident)
   ICMP6_FILTER_SETPASS (ICMP6_TIME_EXCEEDED, &filter);
   ICMP6_FILTER_SETPASS (ICMP6_PARAM_PROB, &filter);
 
-  err = setsockopt (fd, IPPROTO_ICMPV6, ICMP6_FILTER, &filter, sizeof (filter));
+  err =
+    setsockopt (fd, IPPROTO_ICMPV6, ICMP6_FILTER, &filter, sizeof (filter));
   if (err)
     {
       close (fd);
@@ -735,7 +720,7 @@ ping_init (int type, int ident)
       close (fd);
       return NULL;
     }
-  
+
   /* Allocate PING structure and initialize it to default values */
   p = malloc (sizeof (*p));
   if (!p)
@@ -747,8 +732,8 @@ ping_init (int type, int ident)
   memset (p, 0, sizeof (*p));
 
   p->ping_fd = fd;
-  p->ping_count = 0;
-  p->ping_interval = PING_INTERVAL;
+  p->ping_count = DEFAULT_PING_COUNT;
+  p->ping_interval = PING_DEFAULT_INTERVAL;
   p->ping_datalen = sizeof (struct icmp6_hdr);
   /* Make sure we use only 16 bits in this field, id for icmp is a u_short.  */
   p->ping_ident = ident & 0xFFFF;
@@ -757,43 +742,12 @@ ping_init (int type, int ident)
 }
 
 static int
-_ping_setbuf (PING *p)
-{
-  if (!p->ping_buffer)
-    {
-      p->ping_buffer = malloc (_PING_BUFLEN (p));
-      if (!p->ping_buffer)
-	return -1;
-    }
-  if (!p->ping_cktab)
-    {
-      p->ping_cktab = malloc (p->ping_cktab_size);
-      if (!p->ping_cktab)
-        return -1;
-      memset (p->ping_cktab, 0, p->ping_cktab_size);
-    }
-  return 0;
-}
-
-static int
-ping_set_data (PING *p, void *data, size_t off, size_t len)
-{
-  if (_ping_setbuf (p))
-    return -1;
-  if (p->ping_datalen < off + len)
-    return -1;
-  memcpy (p->ping_buffer + sizeof (struct icmp6_hdr) + off, data, len);
-
-  return 0;
-}
-
-static int
-ping_xmit (PING *p)
+ping_xmit (PING * p)
 {
   int i, buflen;
   struct icmp6_hdr *icmp6;
 
-  if (_ping_setbuf (p))
+  if (_ping_setbuf (p, USE_IPV6))
     return -1;
 
   buflen = p->ping_datalen + sizeof (struct icmp6_hdr);
@@ -805,13 +759,12 @@ ping_xmit (PING *p)
   icmp6->icmp6_type = ICMP6_ECHO_REQUEST;
   icmp6->icmp6_code = 0;
   /* The checksum will be calculated by the TCP/IP stack.  */
-  icmp6->icmp6_cksum = 0; 
+  icmp6->icmp6_cksum = 0;
   icmp6->icmp6_id = htons (p->ping_ident);
   icmp6->icmp6_seq = htons (p->ping_num_xmit);
 
-  i = sendto (p->ping_fd, (char *)p->ping_buffer, buflen, 0,
-	      (struct sockaddr*) &p->ping_dest,
-	      sizeof (p->ping_dest));
+  i = sendto (p->ping_fd, (char *) p->ping_buffer, buflen, 0,
+	      (struct sockaddr *) &p->ping_dest.ping_sockaddr6, sizeof (p->ping_dest.ping_sockaddr6));
   if (i < 0)
     perror ("ping: sendto");
   else
@@ -826,21 +779,19 @@ ping_xmit (PING *p)
 }
 
 static int
-my_echo_reply (PING *p, struct icmp6_hdr *icmp6)
+my_echo_reply (PING * p, struct icmp6_hdr *icmp6)
 {
-  struct ip6_hdr *orig_ip = 
-    (struct ip6_hdr *) (icmp6 + 1);
-  struct icmp6_hdr *orig_icmp = 
-    (struct icmp6_hdr *)(orig_ip + 1);
+  struct ip6_hdr *orig_ip = (struct ip6_hdr *) (icmp6 + 1);
+  struct icmp6_hdr *orig_icmp = (struct icmp6_hdr *) (orig_ip + 1);
 
-  return IN6_ARE_ADDR_EQUAL (&orig_ip->ip6_dst, &ping->ping_dest.sin6_addr)
+  return IN6_ARE_ADDR_EQUAL (&orig_ip->ip6_dst, &ping->ping_dest.ping_sockaddr6.sin6_addr)
     && orig_ip->ip6_nxt == IPPROTO_ICMPV6
     && orig_icmp->icmp6_type == ICMP6_ECHO_REQUEST
     && orig_icmp->icmp6_id == htons (p->ping_ident);
 }
 
 static int
-ping_recv (PING *p)
+ping_recv (PING * p)
 {
   int dupflag, n;
   int hops = -1;
@@ -851,34 +802,35 @@ ping_recv (PING *p)
   char cmsg_data[1024];
 
   iov.iov_base = p->ping_buffer;
-  iov.iov_len = _PING_BUFLEN (p);
-  msg.msg_name = &p->ping_from;
-  msg.msg_namelen = sizeof (p->ping_from);
+  iov.iov_len = _PING_BUFLEN (p, USE_IPV6);
+  msg.msg_name = &p->ping_from.ping_sockaddr6;
+  msg.msg_namelen = sizeof (p->ping_from.ping_sockaddr6);
   msg.msg_iov = &iov;
   msg.msg_iovlen = 1;
   msg.msg_control = cmsg_data;
   msg.msg_controllen = sizeof (cmsg_data);
   msg.msg_flags = 0;
-  
+
   n = recvmsg (p->ping_fd, &msg, 0);
   if (n < 0)
     return -1;
 
-  for (cmsg = CMSG_FIRSTHDR(&msg); cmsg; cmsg = CMSG_NXTHDR (&msg, cmsg))
+  for (cmsg = CMSG_FIRSTHDR (&msg); cmsg; cmsg = CMSG_NXTHDR (&msg, cmsg))
     {
-      if (cmsg->cmsg_level == IPPROTO_IPV6 && cmsg->cmsg_type == IPV6_HOPLIMIT)
+      if (cmsg->cmsg_level == IPPROTO_IPV6
+	  && cmsg->cmsg_type == IPV6_HOPLIMIT)
 	{
-	  hops = *(int *)CMSG_DATA(cmsg);
+	  hops = *(int *) CMSG_DATA (cmsg);
 	  break;
 	}
     }
-  
+
   icmp6 = (struct icmp6_hdr *) p->ping_buffer;
   if (icmp6->icmp6_type == ICMP6_ECHO_REPLY)
     {
       /* We got an echo reply.  */
       if (ntohs (icmp6->icmp6_id) != p->ping_ident)
-	return -1; /* It's not a response to us.  */
+	return -1;		/* It's not a response to us.  */
 
       if (_PING_TST (p, ntohs (icmp6->icmp6_seq) % p->ping_cktab_size))
 	{
@@ -893,28 +845,28 @@ ping_recv (PING *p)
 	  dupflag = 0;
 	}
 
-      print_echo (dupflag, hops, p->ping_closure, &p->ping_dest,
-		  &p->ping_from, icmp6, n);
+      print_echo (dupflag, hops, p->ping_closure, &p->ping_dest.ping_sockaddr6,
+		  &p->ping_from.ping_sockaddr6, icmp6, n);
 
     }
   else
     {
       /* We got an error reply.  */
       if (!my_echo_reply (p, icmp6))
-	return -1; /* It's not for us.  */
+	return -1;		/* It's not for us.  */
 
-      print_icmp_error (&p->ping_from, icmp6, n);
+      print_icmp_error (&p->ping_from.ping_sockaddr6, icmp6, n);
     }
-  
+
   return 0;
 }
 
 static int
-ping_set_dest (PING *ping, char *host)
+ping_set_dest (PING * ping, char *host)
 {
   int err;
   struct addrinfo *result, hints;
-  
+
   memset (&hints, 0, sizeof (hints));
 
   hints.ai_family = AF_INET6;
@@ -923,7 +875,7 @@ ping_set_dest (PING *ping, char *host)
   if (err)
     return 1;
 
-  memcpy (&ping->ping_dest, result->ai_addr, result->ai_addrlen);
+  memcpy (&ping->ping_dest.ping_sockaddr6, result->ai_addr, result->ai_addrlen);
 
   freeaddrinfo (result);
 
