@@ -28,9 +28,6 @@
 #include <sys/time.h>
 #include <signal.h>
 
-#include <netinet/in_systm.h>
-#include <netinet/in.h>
-#include <netinet/ip.h>
 /*#include <netinet/ip_icmp.h>  -- deliberately not including this */
 #ifdef HAVE_NETINET_IP_VAR_H
 # include <netinet/ip_var.h>
@@ -45,39 +42,33 @@
 #include <ctype.h>
 #include <errno.h>
 
-#include "getopt.h"
-#include <icmp.h>
 #include <ping.h>
 #include <ping_impl.h>
 
 static int recv_address (int code, void *closure,
-			struct sockaddr_in *dest, struct sockaddr_in *from,
-			struct ip *ip, icmphdr_t *icmp, int datalen);
+			 struct sockaddr_in *dest, struct sockaddr_in *from,
+			 struct ip *ip, icmphdr_t * icmp, int datalen);
 static void print_address (int dupflag, void *closure,
-			  struct sockaddr_in *dest, struct sockaddr_in *from,
-			  struct ip *ip, icmphdr_t *icmp, int datalen);
+			   struct sockaddr_in *dest, struct sockaddr_in *from,
+			   struct ip *ip, icmphdr_t * icmp, int datalen);
 static void print_address (int dupflag, void *closure,
-			  struct sockaddr_in *dest, struct sockaddr_in *from,
-			  struct ip *ip, icmphdr_t *icmp, int datalen);
+			   struct sockaddr_in *dest, struct sockaddr_in *from,
+			   struct ip *ip, icmphdr_t * icmp, int datalen);
 static int address_finish ();
 
 int
-ping_address (int argc, char **argv)
+ping_address (char *hostname)
 {
   ping_set_type (ping, ICMP_ADDRESS);
   ping_set_event_handler (ping, recv_address, NULL);
-  ping_set_packetsize (ping, 12); /* FIXME: constant */
+  ping_set_packetsize (ping, 12);	/* FIXME: constant */
   ping_set_count (ping, 1);
 
-  if (ping_set_dest (ping, *argv))
-    {
-      fprintf (stderr, "ping: unknown host\n");
-      exit (1);
-    }
+  if (ping_set_dest (ping, hostname))
+    error (EXIT_FAILURE, 0, "unknown host");
 
   printf ("PING %s (%s): sending address mask request\n",
-	 ping->ping_hostname,
-	 inet_ntoa (ping->ping_dest.sin_addr));
+	  ping->ping_hostname, inet_ntoa (ping->ping_dest.ping_sockaddr.sin_addr));
 
   return ping_run (ping, address_finish);
 }
@@ -85,15 +76,15 @@ ping_address (int argc, char **argv)
 
 int
 recv_address (int code, void *closure,
-	     struct sockaddr_in *dest, struct sockaddr_in *from,
-	     struct ip *ip, icmphdr_t *icmp, int datalen)
+	      struct sockaddr_in *dest, struct sockaddr_in *from,
+	      struct ip *ip, icmphdr_t * icmp, int datalen)
 {
   switch (code)
     {
     case PEV_RESPONSE:
     case PEV_DUPLICATE:
       print_address (code == PEV_DUPLICATE,
-		    closure, dest, from, ip, icmp, datalen);
+		     closure, dest, from, ip, icmp, datalen);
       break;
     case PEV_NOECHO:;
       print_icmp_header (from, ip, icmp, datalen);
@@ -103,14 +94,14 @@ recv_address (int code, void *closure,
 
 void
 print_address (int dupflag, void *closure,
-	      struct sockaddr_in *dest, struct sockaddr_in *from,
-	      struct ip *ip, icmphdr_t *icmp, int datalen)
+	       struct sockaddr_in *dest, struct sockaddr_in *from,
+	       struct ip *ip, icmphdr_t * icmp, int datalen)
 {
   struct in_addr addr;
 
   printf ("%d bytes from %s: icmp_seq=%u", datalen,
-	 inet_ntoa (*(struct in_addr *)&from->sin_addr.s_addr),
-	 icmp->icmp_seq);
+	  inet_ntoa (*(struct in_addr *) &from->sin_addr.s_addr),
+	  icmp->icmp_seq);
   if (dupflag)
     printf (" (DUP!)");
   addr.s_addr = icmp->icmp_mask;
