@@ -1,4 +1,5 @@
-/* Copyright (C) 1998, 2001, 2002, 2004, 2005, 2007 Free Software Foundation, Inc.
+/* Copyright (C) 1998, 2001, 2002, 2004, 2005, 2007, 2008
+   Free Software Foundation, Inc.
 
    This file is part of GNU Inetutils.
 
@@ -22,14 +23,20 @@
 #endif
 
 #include <sys/types.h>
+#include <sys/socket.h>
 #include <sys/time.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 #include <xalloc.h>
 
+#include "ping_common.h"
+
 extern unsigned char *data_buffer;
 extern size_t data_length;
 
+static void _ping_freebuf (PING * p);
+
 size_t
 ping_cvt_number (const char *optarg, size_t maxval, int allow_zero)
 {
@@ -38,25 +45,19 @@ ping_cvt_number (const char *optarg, size_t maxval, int allow_zero)
 
   n = strtoul (optarg, &p, 0);
   if (*p)
-    {
-      fprintf (stderr, "Invalid value (`%s' near `%s')\n", optarg, p);
-      exit (1);
-    }
+    error (EXIT_FAILURE, 0, "invalid value (`%s' near `%s')", optarg, p);
+
   if (n == 0 && !allow_zero)
-    {
-      fprintf (stderr, "Option value too small: %s\n", optarg);
-      exit (1);
-    }
+    error (EXIT_FAILURE, 0, "option value too small: %s", optarg);
+
   if (maxval && n > maxval)
-    {
-      fprintf (stderr, "Option value too big: %s\n", optarg);
-      exit (1);
-    }
+    error (EXIT_FAILURE, 0, "option value too big: %s", optarg);
+
   return n;
 }
 
 void
-init_data_buffer (u_char *pat, int len)
+init_data_buffer (u_char * pat, int len)
 {
   int i = 0;
   u_char *p;
@@ -83,17 +84,16 @@ init_data_buffer (u_char *pat, int len)
 }
 
 void
-decode_pattern (const char *text, int *pattern_len, unsigned char *pattern_data)
+decode_pattern (const char *text, int *pattern_len,
+		unsigned char *pattern_data)
 {
   int i, c, off;
 
   for (i = 0; *text && i < *pattern_len; i++)
     {
       if (sscanf (text, "%2x%n", &c, &off) != 1)
-	{
-	  fprintf (stderr, "ping: error in pattern near %s\n", text);
-	  exit (1);
-	}
+        error (EXIT_FAILURE, 0, "error in pattern near %s", text);
+
       text += off;
     }
   *pattern_len = i;
@@ -126,38 +126,91 @@ double
 nsqrt (double a, double prec)
 {
   double x0, x1;
-  
+
   if (a < 0)
-    return 0; 
+    return 0;
   if (a < prec)
     return 0;
-  x1 = a/2;
+  x1 = a / 2;
   do
     {
       x0 = x1;
-      x1 = (x0 + a/x0) / 2;
+      x1 = (x0 + a / x0) / 2;
     }
   while (nabs (x1 - x0) > prec);
 
   return x1;
 }
 
-void
-show_license (void)
+int
+_ping_setbuf (PING * p, bool use_ipv6)
 {
-  static char license_text[] =
-"   This program is free software; you can redistribute it and/or modify\n"
-"   it under the terms of the GNU General Public License as published by\n"
-"   the Free Software Foundation; either version 3, or (at your option)\n"
-"   any later version.\n"
-"\n"
-"   This program is distributed in the hope that it will be useful,\n"
-"   but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-"   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-"   GNU General Public License for more details.\n"
-"\n"
-"   You should have received a copy of the GNU General Public License\n"
-"   along with this program; if not, write to the Free Software\n"
-"   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n";
-  printf ("%s", license_text);
+  if (!p->ping_buffer) {
+    p->ping_buffer = malloc (_PING_BUFLEN (p, use_ipv6));
+    if (!p->ping_buffer)
+      return -1;
+  }
+  if (!p->ping_cktab) {
+    p->ping_cktab = malloc (p->ping_cktab_size);
+    if (!p->ping_cktab)
+      return -1;
+    memset (p->ping_cktab, 0, p->ping_cktab_size);
+  }
+  return 0;
 }
+
+int
+ping_set_data (PING * p, void *data, size_t off, size_t len, bool use_ipv6)
+{
+  icmphdr_t *icmp;
+
+  if (_ping_setbuf (p, use_ipv6))
+    return -1;
+  if (p->ping_datalen < off + len)
+    return -1;
+
+  icmp = (icmphdr_t *) p->ping_buffer;
+  memcpy (icmp->icmp_data + off, data, len);
+
+  return 0;
+}
+
+void
+ping_set_count (PING * ping, size_t count)
+{
+  ping->ping_count = count;
+}
+
+void
+ping_set_sockopt (PING * ping, int opt, void *val, int valsize)
+{
+  setsockopt (ping->ping_fd, SOL_SOCKET, opt, (char *) &val, valsize);
+}
+
+void
+ping_set_interval (PING * ping, size_t interval)
+{
+  ping->ping_interval = interval;
+}
+
+void
+_ping_freebuf (PING * p)
+{
+  if (p->ping_buffer)
+    {
+      free (p->ping_buffer);
+      p->ping_buffer = NULL;
+    }
+  if (p->ping_cktab)
+    {
+      free (p->ping_cktab);
+      p->ping_cktab = NULL;
+    }
+}
+
+void
+ping_unset_data (PING * p)
+{
+  _ping_freebuf (p);
+}
+
