@@ -27,9 +27,6 @@
 #include <sys/time.h>
 #include <signal.h>
 
-#include <netinet/in_systm.h>
-#include <netinet/in.h>
-#include <netinet/ip.h>
 /*#include <netinet/ip_icmp.h>  -- deliberately not including this */
 #ifdef HAVE_NETINET_IP_VAR_H
 # include <netinet/ip_var.h>
@@ -45,12 +42,10 @@
 #include <errno.h>
 #include <limits.h>
 
-#include <icmp.h>
 #include <ping.h>
-#include "ping_common.h"
 #include "ping_impl.h"
 
-#define	NROUTES		9		/* number of record route slots */
+#define NROUTES		9	/* number of record route slots */
 #ifndef MAX_IPOPTLEN
 # define MAX_IPOPTLEN 40
 #endif
@@ -58,31 +53,28 @@
 #include <xalloc.h>
 
 static int handler (int code, void *closure,
-		   struct sockaddr_in *dest, struct sockaddr_in *from,
-		   struct ip *ip, icmphdr_t *icmp, int datalen);
+		    struct sockaddr_in *dest, struct sockaddr_in *from,
+		    struct ip *ip, icmphdr_t * icmp, int datalen);
 int print_echo (int dup, struct ping_stat *stat,
-	      struct sockaddr_in *dest, struct sockaddr_in *from,
-	      struct ip *ip, icmphdr_t *icmp, int datalen);
+		struct sockaddr_in *dest, struct sockaddr_in *from,
+		struct ip *ip, icmphdr_t * icmp, int datalen);
 static int echo_finish (void);
 
 void print_icmp_header (struct sockaddr_in *from,
-			      struct ip *ip, icmphdr_t *icmp, int len);
+			struct ip *ip, icmphdr_t * icmp, int len);
 static void print_ip_opt (struct ip *ip, int hlen);
 
 int
-ping_echo (int argc, char **argv)
+ping_echo (char *hostname)
 {
 #ifdef IP_OPTIONS
   char rspace[3 + 4 * NROUTES + 1];	/* record route space */
 #endif
   struct ping_stat ping_stat;
+  int status;
 
   if (options & OPT_FLOOD && options & OPT_INTERVAL)
-    {
-      fprintf (stderr,
-	      "ping: -f and -i incompatible options.\n");
-      return 2;
-    }
+    error (EXIT_FAILURE, 0, "-f and -i incompatible options");
 
   memset (&ping_stat, 0, sizeof (ping_stat));
   ping_stat.tmin = 999999999.0;
@@ -91,51 +83,46 @@ ping_echo (int argc, char **argv)
   ping_set_packetsize (ping, data_length);
   ping_set_event_handler (ping, handler, &ping_stat);
 
-  if (ping_set_dest (ping, *argv))
-    {
-      fprintf (stderr, "ping: unknown host\n");
-      exit (1);
-    }
+  if (ping_set_dest (ping, hostname))
+    error (EXIT_FAILURE, 0, "unknown host");
 
   if (options & OPT_RROUTE)
     {
 #ifdef IP_OPTIONS
       memset (rspace, 0, sizeof (rspace));
       rspace[IPOPT_OPTVAL] = IPOPT_RR;
-      rspace[IPOPT_OLEN] = sizeof (rspace)-1;
+      rspace[IPOPT_OLEN] = sizeof (rspace) - 1;
       rspace[IPOPT_OFFSET] = IPOPT_MINOFF;
       if (setsockopt (ping->ping_fd, IPPROTO_IP,
-		     IP_OPTIONS, rspace, sizeof (rspace)) < 0)
-	{
-	  perror ("ping: record route");
-	  exit (2);
-	}
+		      IP_OPTIONS, rspace, sizeof (rspace)) < 0)
+        error (EXIT_FAILURE, errno, NULL);
 #else
-      fprintf (stderr,
-	      "ping: record route not available in this implementation.\n");
-      exit (2);
+      error (EXIT_FAILURE, 0, "record route not available in this "
+             "implementation.");
 #endif /* IP_OPTIONS */
     }
 
   printf ("PING %s (%s): %d data bytes\n",
-	 ping->ping_hostname,
-	 inet_ntoa (ping->ping_dest.sin_addr),
-	 data_length);
+	  ping->ping_hostname,
+	  inet_ntoa (ping->ping_dest.ping_sockaddr.sin_addr), data_length);
 
-  return ping_run (ping, echo_finish);
+  status = ping_run (ping, echo_finish);
+  free (ping->ping_hostname);
+  return status;
 }
 
 int
 handler (int code, void *closure,
-	struct sockaddr_in *dest, struct sockaddr_in *from,
-	struct ip *ip, icmphdr_t *icmp, int datalen)
+	 struct sockaddr_in *dest, struct sockaddr_in *from,
+	 struct ip *ip, icmphdr_t * icmp, int datalen)
 {
   switch (code)
     {
     case PEV_RESPONSE:
     case PEV_DUPLICATE:
       print_echo (code == PEV_DUPLICATE,
-		   (struct ping_stat*)closure, dest, from, ip, icmp, datalen);
+		  (struct ping_stat *) closure, dest, from, ip, icmp,
+		  datalen);
       break;
     case PEV_NOECHO:;
       print_icmp_header (from, ip, icmp, datalen);
@@ -145,8 +132,8 @@ handler (int code, void *closure,
 
 int
 print_echo (int dupflag, struct ping_stat *ping_stat,
-	   struct sockaddr_in *dest, struct sockaddr_in *from,
-	   struct ip *ip, icmphdr_t *icmp, int datalen)
+	    struct sockaddr_in *dest, struct sockaddr_in *from,
+	    struct ip *ip, icmphdr_t * icmp, int datalen)
 {
   int hlen;
   struct timeval tv;
@@ -162,7 +149,7 @@ print_echo (int dupflag, struct ping_stat *ping_stat,
   datalen -= hlen;
 
   /* Do timing */
-  if (PING_TIMING (datalen-8))
+  if (PING_TIMING (datalen - 8))
     {
       struct timeval tv1, *tp;
 
@@ -173,10 +160,10 @@ print_echo (int dupflag, struct ping_stat *ping_stat,
       memcpy (&tv1, tp, sizeof (tv1));
       tvsub (&tv, &tv1);
 
-      triptime = ((double)tv.tv_sec) * 1000.0 +
-	          ((double)tv.tv_usec) / 1000.0;
+      triptime = ((double) tv.tv_sec) * 1000.0 +
+	((double) tv.tv_usec) / 1000.0;
       ping_stat->tsum += triptime;
-      ping_stat->tsumsq += triptime*triptime;
+      ping_stat->tsumsq += triptime * triptime;
       if (triptime < ping_stat->tmin)
 	ping_stat->tmin = triptime;
       if (triptime > ping_stat->tmax)
@@ -192,8 +179,8 @@ print_echo (int dupflag, struct ping_stat *ping_stat,
     }
 
   printf ("%d bytes from %s: icmp_seq=%u", datalen,
-	 inet_ntoa (*(struct in_addr *)&from->sin_addr.s_addr),
-	 icmp->icmp_seq);
+	  inet_ntoa (*(struct in_addr *) &from->sin_addr.s_addr),
+	  icmp->icmp_seq);
   printf (" ttl=%d", ip->ip_ttl);
   if (timing)
     printf (" time=%.3f ms", triptime);
@@ -212,16 +199,16 @@ ipaddr2str (struct in_addr ina)
   struct hostent *hp;
 
   if (options & OPT_NUMERIC
-      || !(hp = gethostbyaddr ((char *)&ina, 4, AF_INET)))
+      || !(hp = gethostbyaddr ((char *) &ina, 4, AF_INET)))
     return xstrdup (inet_ntoa (ina));
   else
     {
       char *ipstr = inet_ntoa (ina);
       int len = strlen (hp->h_name) + 1;
       char *buf;
-      
+
       if (ipstr)
-	len += strlen (ipstr) + 3; /* a pair of parentheses and a space */
+	len += strlen (ipstr) + 3;	/* a pair of parentheses and a space */
 
       buf = xmalloc (len);
       if (ipstr)
@@ -234,59 +221,61 @@ ipaddr2str (struct in_addr ina)
 
 #define NITEMS(a) sizeof(a)/sizeof((a)[0])
 
-struct icmp_diag {
+struct icmp_diag
+{
   int type;
   char *text;
   void (*fun) (icmphdr_t *, void *data);
   void *data;
 };
 
-struct icmp_code_descr {
+struct icmp_code_descr
+{
   int code;
   char *diag;
-} icmp_code_descr[] = {
-  { ICMP_NET_UNREACH,    "Destination Net Unreachable" },
-  { ICMP_HOST_UNREACH,   "Destination Host Unreachable" },
-  { ICMP_PROT_UNREACH,   "Destination Protocol Unreachable" },
-  { ICMP_PORT_UNREACH,   "Destination Port Unreachable" },
-  { ICMP_FRAG_NEEDED,    "Fragmentation needed and DF set" },
-  { ICMP_SR_FAILED,      "Source Route Failed" },
-  { ICMP_NET_UNKNOWN,    "Network Unknown" },
-  { ICMP_HOST_UNKNOWN,   "Host Unknown" },
-  { ICMP_HOST_ISOLATED,  "Host Isolated" },
-  { ICMP_NET_UNR_TOS,    "Destination Network Unreachable At This TOS" },
-  { ICMP_HOST_UNR_TOS,   "Destination Host Unreachable At This TOS" },
+} icmp_code_descr[] =
+  {
+    {ICMP_NET_UNREACH, "Destination Net Unreachable"},
+    {ICMP_HOST_UNREACH, "Destination Host Unreachable"},
+    {ICMP_PROT_UNREACH, "Destination Protocol Unreachable"},
+    {ICMP_PORT_UNREACH, "Destination Port Unreachable"},
+    {ICMP_FRAG_NEEDED, "Fragmentation needed and DF set"},
+    {ICMP_SR_FAILED, "Source Route Failed"},
+    {ICMP_NET_UNKNOWN, "Network Unknown"},
+    {ICMP_HOST_UNKNOWN, "Host Unknown"},
+    {ICMP_HOST_ISOLATED, "Host Isolated"},
+    {ICMP_NET_UNR_TOS, "Destination Network Unreachable At This TOS"},
+    {ICMP_HOST_UNR_TOS, "Destination Host Unreachable At This TOS"},
 #ifdef ICMP_PKT_FILTERED
-  { ICMP_PKT_FILTERED,   "Packet Filtered" },
+    {ICMP_PKT_FILTERED, "Packet Filtered"},
 #endif
 #ifdef ICMP_PREC_VIOLATION
-  { ICMP_PREC_VIOLATION, "Precedence Violation" },
+    {ICMP_PREC_VIOLATION, "Precedence Violation"},
 #endif
 #ifdef ICMP_PREC_CUTOFF
-  { ICMP_PREC_CUTOFF,    "Precedence Cutoff" },
+    {ICMP_PREC_CUTOFF, "Precedence Cutoff"},
 #endif
-
-  { ICMP_REDIR_NET,      "Redirect Network" },
-  { ICMP_REDIR_HOST,     "Redirect Host" },
-  { ICMP_REDIR_NETTOS,   "Redirect Type of Service and Network" },
-  { ICMP_REDIR_HOSTTOS,  "Redirect Type of Service and Host" },
-
-  { ICMP_EXC_TTL,        "Time to live exceeded" },
-  { ICMP_EXC_FRAGTIME,   "Frag reassembly time exceeded" },
-};
+    {ICMP_REDIR_NET, "Redirect Network"},
+    {ICMP_REDIR_HOST, "Redirect Host"},
+    {ICMP_REDIR_NETTOS, "Redirect Type of Service and Network"},
+    {ICMP_REDIR_HOSTTOS, "Redirect Type of Service and Host"},
+    {ICMP_EXC_TTL, "Time to live exceeded"},
+    {ICMP_EXC_FRAGTIME, "Frag reassembly time exceeded"}
+  };
 
 static void
 print_icmp_code (int code, char *prefix)
 {
   struct icmp_code_descr *p;
 
-  for (p = icmp_code_descr; p < icmp_code_descr + NITEMS(icmp_code_descr); p++)
+  for (p = icmp_code_descr; p < icmp_code_descr + NITEMS (icmp_code_descr);
+       p++)
     if (p->code == code)
       {
 	printf ("%s\n", p->diag);
 	return;
       }
-  
+
   printf ("%s, Unknown Code: %d\n", prefix, code);
 }
 
@@ -297,52 +286,53 @@ print_ip_header (struct ip *ip)
   u_char *cp;
 
   hlen = ip->ip_hl << 2;
-  cp = (u_char *)ip + 20;		/* point to options */
+  cp = (u_char *) ip + 20;	/* point to options */
 
-  printf ("Vr HL TOS  Len   ID Flg  off TTL Pro  cks      Src      Dst Data\n");
-  printf (" %1x  %1x  %02x %04x %04x",
-	 ip->ip_v, ip->ip_hl, ip->ip_tos, ip->ip_len, ip->ip_id);
+  printf
+    ("Vr HL TOS  Len   ID Flg  off TTL Pro  cks      Src      Dst Data\n");
+  printf (" %1x  %1x  %02x %04x %04x", ip->ip_v, ip->ip_hl, ip->ip_tos,
+	  ip->ip_len, ip->ip_id);
   printf ("   %1x %04x", ((ip->ip_off) & 0xe000) >> 13,
-	 (ip->ip_off) & 0x1fff);
+	  (ip->ip_off) & 0x1fff);
   printf ("  %02x  %02x %04x", ip->ip_ttl, ip->ip_p, ip->ip_sum);
   printf (" %s ", inet_ntoa (*((struct in_addr *) &ip->ip_src)));
   printf (" %s ", inet_ntoa (*((struct in_addr *) &ip->ip_dst)));
-  while (hlen-- > 20) 
+  while (hlen-- > 20)
     printf ("%02x", *cp++);
 
   printf ("\n");
 }
 
 void
-print_ip_data (icmphdr_t *icmp, void *data)
+print_ip_data (icmphdr_t * icmp, void *data)
 {
   int hlen;
   u_char *cp;
   struct ip *ip = &icmp->icmp_ip;
-  
+
   print_ip_header (ip);
 
   hlen = ip->ip_hl << 2;
-  cp = (u_char *)ip + hlen;
+  cp = (u_char *) ip + hlen;
 
   if (ip->ip_p == 6)
     printf ("TCP: from port %u, to port %u (decimal)\n",
-	   (*cp * 256 + *(cp + 1)), (*(cp + 2) * 256 + *(cp + 3)));
+	    (*cp * 256 + *(cp + 1)), (*(cp + 2) * 256 + *(cp + 3)));
   else if (ip->ip_p == 17)
     printf ("UDP: from port %u, to port %u (decimal)\n",
-	   (*cp * 256 + *(cp + 1)), (*(cp + 2) * 256 + *(cp + 3)));
+	    (*cp * 256 + *(cp + 1)), (*(cp + 2) * 256 + *(cp + 3)));
 
 }
 
 static void
-print_icmp (icmphdr_t *icmp, void *data)
+print_icmp (icmphdr_t * icmp, void *data)
 {
   print_icmp_code (icmp->icmp_code, data);
   print_ip_data (icmp, NULL);
 }
 
 static void
-print_parameterprob (icmphdr_t *icmp, void *data)
+print_parameterprob (icmphdr_t * icmp, void *data)
 {
   printf ("Parameter problem: IP address = %s\n",
 	  inet_ntoa (icmp->icmp_gwaddr));
@@ -350,43 +340,43 @@ print_parameterprob (icmphdr_t *icmp, void *data)
 }
 
 struct icmp_diag icmp_diag[] = {
-  { ICMP_ECHOREPLY, "Echo Reply", NULL },
-  { ICMP_DEST_UNREACH, NULL, print_icmp, "Dest Unreachable" },
-  { ICMP_SOURCE_QUENCH, "Source Quench", print_ip_data },
-  { ICMP_REDIRECT, NULL, print_icmp, "Redirect" },
-  { ICMP_ECHO, "Echo Request", NULL },
-  { ICMP_TIME_EXCEEDED, NULL, print_icmp, "Time exceeded" },
-  { ICMP_PARAMETERPROB, NULL, print_parameterprob },
-  { ICMP_TIMESTAMP, "Timestamp", NULL },
-  { ICMP_TIMESTAMPREPLY, "Timestamp Reply", NULL },
-  { ICMP_INFO_REQUEST, "Information Request", NULL },
+  {ICMP_ECHOREPLY, "Echo Reply", NULL},
+  {ICMP_DEST_UNREACH, NULL, print_icmp, "Dest Unreachable"},
+  {ICMP_SOURCE_QUENCH, "Source Quench", print_ip_data},
+  {ICMP_REDIRECT, NULL, print_icmp, "Redirect"},
+  {ICMP_ECHO, "Echo Request", NULL},
+  {ICMP_TIME_EXCEEDED, NULL, print_icmp, "Time exceeded"},
+  {ICMP_PARAMETERPROB, NULL, print_parameterprob},
+  {ICMP_TIMESTAMP, "Timestamp", NULL},
+  {ICMP_TIMESTAMPREPLY, "Timestamp Reply", NULL},
+  {ICMP_INFO_REQUEST, "Information Request", NULL},
 #ifdef ICMP_MASKREQ
-  { ICMP_MASKREPLY, "Address Mask Reply", NULL },
+  {ICMP_MASKREPLY, "Address Mask Reply", NULL},
 #endif
 };
 
 void
 print_icmp_header (struct sockaddr_in *from,
-		   struct ip *ip, icmphdr_t *icmp, int len)
+		   struct ip *ip, icmphdr_t * icmp, int len)
 {
   int hlen;
   struct ip *orig_ip;
   char *s;
   struct icmp_diag *p;
-  
+
   /* Length of the IP header */
   hlen = ip->ip_hl << 2;
   /* Original IP header */
   orig_ip = &icmp->icmp_ip;
 
   if (!(options & OPT_VERBOSE
-	|| orig_ip->ip_dst.s_addr == ping->ping_dest.sin_addr.s_addr))
+	|| orig_ip->ip_dst.s_addr == ping->ping_dest.ping_sockaddr.sin_addr.s_addr))
     return;
 
-  printf ("%d bytes from %s: ", len-hlen, s = ipaddr2str (from->sin_addr));
+  printf ("%d bytes from %s: ", len - hlen, s = ipaddr2str (from->sin_addr));
   free (s);
 
-  for (p = icmp_diag; p < icmp_diag + NITEMS(icmp_diag); p++)
+  for (p = icmp_diag; p < icmp_diag + NITEMS (icmp_diag); p++)
     {
       if (p->type == icmp->icmp_type)
 	{
@@ -408,15 +398,15 @@ print_ip_opt (struct ip *ip, int hlen)
   static int old_rrlen;
   static char old_rr[MAX_IPOPTLEN];
 
-  cp = (u_char *)(ip + 1);
+  cp = (u_char *) (ip + 1);
 
-  for (; hlen > (int)sizeof (struct ip); --hlen, ++cp)
+  for (; hlen > (int) sizeof (struct ip); --hlen, ++cp)
     switch (*cp)
       {
       case IPOPT_EOL:
 	hlen = 0;
 	break;
-	
+
       case IPOPT_LSRR:
 	printf ("\nLSRR: ");
 	hlen -= 2;
@@ -426,9 +416,9 @@ print_ip_opt (struct ip *ip, int hlen)
 	  for (;;)
 	    {
 	      l = *++cp;
-	      l = (l<<8) + *++cp;
-	      l = (l<<8) + *++cp;
-	      l = (l<<8) + *++cp;
+	      l = (l << 8) + *++cp;
+	      l = (l << 8) + *++cp;
+	      l = (l << 8) + *++cp;
 	      if (l == 0)
 		{
 		  printf ("\t0.0.0.0");
@@ -437,7 +427,7 @@ print_ip_opt (struct ip *ip, int hlen)
 		{
 		  struct in_addr ina;
 		  char *s;
-		  
+
 		  ina.s_addr = ntohl (l);
 		  printf ("\t%s", s = ipaddr2str (ina));
 		  free (s);
@@ -449,10 +439,10 @@ print_ip_opt (struct ip *ip, int hlen)
 	      putchar ('\n');
 	    }
 	break;
-	
+
       case IPOPT_RR:
-	j = *++cp;	      
-	i = *++cp;		
+	j = *++cp;
+	i = *++cp;
 	hlen -= 2;
 	if (i > j)
 	  i = j;
@@ -460,9 +450,8 @@ print_ip_opt (struct ip *ip, int hlen)
 	if (i <= 0)
 	  continue;
 	if (i == old_rrlen
-	    && cp == (u_char *)(ip + 1) + 2
-	    && !memcmp ((char *)cp, old_rr, i)
-	    && !(options & OPT_FLOOD))
+	    && cp == (u_char *) (ip + 1) + 2
+	    && !memcmp ((char *) cp, old_rr, i) && !(options & OPT_FLOOD))
 	  {
 	    printf ("\t (same route)");
 	    i = ((i + 3) / 4) * 4;
@@ -483,9 +472,9 @@ print_ip_opt (struct ip *ip, int hlen)
 	for (;;)
 	  {
 	    l = *++cp;
-	    l = (l<<8) + *++cp;
-	    l = (l<<8) + *++cp;
-	    l = (l<<8) + *++cp;
+	    l = (l << 8) + *++cp;
+	    l = (l << 8) + *++cp;
+	    l = (l << 8) + *++cp;
 	    if (l == 0)
 	      {
 		printf ("\t0.0.0.0");
@@ -494,7 +483,7 @@ print_ip_opt (struct ip *ip, int hlen)
 	      {
 		struct in_addr ina;
 		char *s;
-		  
+
 		ina.s_addr = ntohl (l);
 		printf ("\t%s", s = ipaddr2str (ina));
 		free (s);
@@ -512,11 +501,11 @@ print_ip_opt (struct ip *ip, int hlen)
 	    putchar ('\n');
 	  }
 	break;
-	
+
       case IPOPT_NOP:
 	printf ("\nNOP");
 	break;
-	
+
       default:
 	printf ("\nunknown option %x", *cp);
 	break;
@@ -529,16 +518,13 @@ echo_finish ()
   ping_finish ();
   if (ping->ping_num_recv && PING_TIMING (data_length))
     {
-      struct ping_stat *ping_stat = (struct ping_stat*)ping->ping_closure;
+      struct ping_stat *ping_stat = (struct ping_stat *) ping->ping_closure;
       double total = ping->ping_num_recv + ping->ping_num_rept;
-      double avg = ping_stat->tsum/total;
+      double avg = ping_stat->tsum / total;
       double vari = ping_stat->tsumsq / total - avg * avg;
 
       printf ("round-trip min/avg/max/stddev = %.3f/%.3f/%.3f/%.3f ms\n",
-	      ping_stat->tmin,
-	      avg,
-	      ping_stat->tmax,
-	      nsqrt (vari, 0.0005));
+	      ping_stat->tmin, avg, ping_stat->tmax, nsqrt (vari, 0.0005));
     }
-  exit (ping->ping_num_recv == 0);
+  return (ping->ping_num_recv == 0);
 }
