@@ -27,9 +27,6 @@
 #include <sys/time.h>
 #include <signal.h>
 
-#include <netinet/in_systm.h>
-#include <netinet/in.h>
-#include <netinet/ip.h>
 /*#include <netinet/ip_icmp.h>  -- deliberately not including this */
 #ifdef HAVE_NETINET_IP_VAR_H
 # include <netinet/ip_var.h>
@@ -44,13 +41,11 @@
 #include <ctype.h>
 #include <errno.h>
 
-#include "getopt.h"
-#include <icmp.h>
 #include <ping.h>
 #include <ping_impl.h>
 
 int
-ping_router (int argc, char **argv)
+ping_router (char *hostname)
 {
   return 0;
 }
