@@ -27,24 +27,35 @@
  * SUCH DAMAGE.
  */
 
-#ifndef lint
-static char copyright[] = "@(#) Copyright (c) 1983, 1993\n\
-	The Regents of the University of California.  All rights reserved.\n";
-#endif /* not lint */
+/* Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Free Software Foundation, Inc.
 
-#ifndef lint
-static char sccsid[] = "@(#)rexecd.c	8.1 (Berkeley) 6/4/93";
-#endif /* not lint */
+   This file is part of GNU Inetutils.
+
+   GNU Inetutils is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
+
+   GNU Inetutils is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with GNU Inetutils; see the file COPYING.  If not, write
+   to the Free Software Foundation, Inc., 51 Franklin Street,
+   Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
 #include <sys/types.h>
 #include <sys/param.h>
 #include <sys/ioctl.h>
 #ifdef HAVE_SYS_FILIO_H
-#include <sys/filio.h>
+# include <sys/filio.h>
 #endif
 #include <sys/socket.h>
 #ifdef TIME_WITH_SYS_TIME
@@ -68,21 +79,23 @@ static char sccsid[] = "@(#)rexecd.c	8.1 (Berkeley) 6/4/93";
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <grp.h>
 #ifdef HAVE_CRYPT_H
 # include <crypt.h>
 #endif
 #include <getopt.h>
 #ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>
+# include <sys/select.h>
 #endif
 #ifdef HAVE_STDARG_H
-#include <stdarg.h>
+# include <stdarg.h>
 #else
-#include <varargs.h>
+# include <varargs.h>
 #endif
 #ifdef HAVE_SHADOW_H
 # include <shadow.h>
 #endif
+#include <progname.h>
 
 void error (const char *fmt, ...);
 void usage (void);
@@ -101,7 +114,6 @@ static struct option long_options[] = {
  *	command\0
  *	data
  */
-/*ARGSUSED*/
 int
 main (int argc, char **argv)
 {
@@ -109,6 +121,8 @@ main (int argc, char **argv)
   int fromlen, sockfd = STDIN_FILENO;
   int c;
 
+  set_program_name (argv[0]);
+  
   while ((c = getopt_long (argc, argv, short_options, long_options, NULL))
 	 != EOF)
     {
@@ -144,9 +158,9 @@ char *envinit[] = { homedir, shell, path, username, logname, 0 };
 extern char **environ;
 
 #ifdef HAVE_STRUCT_SOCKADDR_IN_SIN_LEN
-struct sockaddr_in asin = { sizeof (asin), AF_INET };
+struct sockaddr_in a_sin = { sizeof (a_sin), AF_INET };
 #else
-struct sockaddr_in asin = { AF_INET };
+struct sockaddr_in a_sin = { AF_INET };
 #endif
 
 char *getstr (const char *);
@@ -213,7 +227,7 @@ doit (int f, struct sockaddr_in *fromp)
       s = socket (AF_INET, SOCK_STREAM, 0);
       if (s < 0)
 	exit (1);
-      if (bind (s, (struct sockaddr *) &asin, sizeof (asin)) < 0)
+      if (bind (s, (struct sockaddr *) &a_sin, sizeof (a_sin)) < 0)
 	exit (1);
       alarm (60);
       fromp->sin_port = htons (port);
@@ -332,12 +346,10 @@ doit (int f, struct sockaddr_in *fromp)
   exit (1);
 }
 
-/*VARARGS1*/
 void
 error (const char *fmt, ...)
 {
   va_list ap;
-  int len;
   char buf[BUFSIZ];
 #if defined(HAVE_STDARG_H) && defined(__STDC__) && __STDC__
   va_start (ap, fmt);
