@@ -27,19 +27,31 @@
  * SUCH DAMAGE.
  */
 
-#ifndef lint
-static char copyright[] = "@(#) Copyright (c) 1983, 1993\n\
-	The Regents of the University of California.  All rights reserved.\n";
-#endif /* not lint */
+/* Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Free Software Foundation, Inc.
 
-#ifndef lint
-static char sccsid[] = "@(#)talk.c	8.1 (Berkeley) 6/6/93";
-#endif /* not lint */
+   This file is part of GNU Inetutils.
+
+   GNU Inetutils is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
+
+   GNU Inetutils is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with GNU Inetutils; see the file COPYING.  If not, write
+   to the Free Software Foundation, Inc., 51 Franklin Street,
+   Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 #include <getopt.h>
+#include <stdlib.h>
 
 #include "talk.h"
 
@@ -66,14 +78,12 @@ static struct option long_options[] = {
   {0}
 };
 
-char *program_name;
-
 int
 main (int argc, char *argv[])
 {
   int c;
 
-  program_name = argv[0];
+  set_program_name (argv[0]);
 
   while ((c = getopt_long (argc, argv, short_options, long_options, NULL))
 	 != EOF)
