@@ -1,10 +1,10 @@
-/* Copyright (C) 1998,2001 Free Software Foundation, Inc.
+/* Copyright (C) 1998,2001,2007 Free Software Foundation, Inc.
 
    This file is part of GNU Inetutils.
 
    GNU Inetutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Inetutils is distributed in the hope that it will be useful,
@@ -54,16 +54,17 @@ extern char *hostname;
 
 #define os2sin_addr(cp) (((struct sockaddr_in *)&(cp))->sin_addr)
 
-extern CTL_MSG *find_request (CTL_MSG *request);
-extern CTL_MSG *find_match (CTL_MSG *request);
-extern int process_request(CTL_MSG *mp, struct sockaddr_in *sa_in, CTL_RESPONSE *rp);
+extern CTL_MSG *find_request (CTL_MSG * request);
+extern CTL_MSG *find_match (CTL_MSG * request);
+extern int process_request (CTL_MSG * mp, struct sockaddr_in *sa_in,
+			    CTL_RESPONSE * rp);
 
-extern int print_request (const char *cp, CTL_MSG *mp);
-extern int print_response (const char *cp, CTL_RESPONSE *rp);
+extern int print_request (const char *cp, CTL_MSG * mp);
+extern int print_response (const char *cp, CTL_RESPONSE * rp);
 
-extern int insert_table (CTL_MSG *request, CTL_RESPONSE *response);
+extern int insert_table (CTL_MSG * request, CTL_RESPONSE * response);
 extern int delete_invite (unsigned long id_num);
 extern int new_id (void);
 extern void read_acl (char *config_file);
-extern int acl_match (CTL_MSG *msg, struct sockaddr_in *sa_in);
-extern int announce (CTL_MSG *request, char *remote_machine);
+extern int acl_match (CTL_MSG * msg, struct sockaddr_in *sa_in);
+extern int announce (CTL_MSG * request, char *remote_machine);
