@@ -22,25 +22,23 @@
 #define D(c) #c
 #define NITEMS(a) (sizeof (a) / sizeof ((a)[0]))
 
-static const char *message_types[] =
-{
-  D(LEAVE_INVITE),
-  D(LOOK_UP),
-  D(DELETE),
-  D(ANNOUNCE)
+static const char *message_types[] = {
+  D (LEAVE_INVITE),
+  D (LOOK_UP),
+  D (DELETE),
+  D (ANNOUNCE)
 };
 
-static const char *answers[] =
-{
-  D(SUCCESS),
-  D(NOT_HERE),
-  D(FAILED),
-  D(MACHINE_UNKNOWN),
-  D(PERMISSION_DENIED),
-  D(UNKNOWN_REQUEST),
-  D(BADVERSION),
-  D(BADADDR),
-  D(BADCTLADDR)
+static const char *answers[] = {
+  D (SUCCESS),
+  D (NOT_HERE),
+  D (FAILED),
+  D (MACHINE_UNKNOWN),
+  D (PERMISSION_DENIED),
+  D (UNKNOWN_REQUEST),
+  D (BADVERSION),
+  D (BADADDR),
+  D (BADCTLADDR)
 };
 
 
@@ -59,7 +57,7 @@ _xlat_num (int num, const char *array[], int size)
 }
 
 int
-print_request (const char *cp, CTL_MSG *mp)
+print_request (const char *cp, CTL_MSG * mp)
 {
   syslog (LOG_DEBUG, "%s: %s: id %d, l_user %s, r_user %s, r_tty %s",
 	  cp, _xlat_num (mp->type, message_types, NITEMS (message_types)),
@@ -68,7 +66,7 @@ print_request (const char *cp, CTL_MSG *mp)
 }
 
 int
-print_response (const char *cp, CTL_RESPONSE *rp)
+print_response (const char *cp, CTL_RESPONSE * rp)
 {
   syslog (LOG_DEBUG, "%s: %s: %s, id %d",
 	  cp,
