@@ -27,12 +27,8 @@
  * SUCH DAMAGE.
  */
 
-#if 0
-static char sccsid[] = "@(#)main.c	8.3 (Berkeley) 5/30/95";
-#endif
-
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
 #include <sys/types.h>
@@ -50,25 +46,25 @@ static char sccsid[] = "@(#)main.c	8.3 (Berkeley) 5/30/95";
 #define OPTS_FORWARDABLE_CREDS       0x00000001
 
 #if 0
-#define FORWARD
+# define FORWARD
 #endif
 
 /*
  * Initialize variables.
  */
 void
-tninit()
+tninit ()
 {
-    init_terminal();
+  init_terminal ();
 
-    init_network();
+  init_network ();
 
-    init_telnet();
+  init_telnet ();
 
-    init_sys();
+  init_sys ();
 
 #if defined(TN3270)
-    init_3270();
+  init_3270 ();
 #endif
 }
 
@@ -149,253 +145,255 @@ usage ()
   try_help ();
 }
 
-static struct option long_options[] =
-{
-  { "ipv4", no_argument, 0, '4'},
-  { "ipv6", no_argument, 0, '6'},
-  { "binary", no_argument, 0, '8' },
-  { "login", no_argument, 0, 'a' },
-  { "no-rc", no_argument, 0, 'c' },
-  { "debug", no_argument, 0, 'd' },
-  { "escape", required_argument, 0, 'e' },
-  { "no-escape", no_argument, 0, 'E' },
-  { "no-login", no_argument, 0, 'K' },
-  { "user", required_argument, 0, 'l' },
-  { "binary-output", no_argument, 0, 'L' },
-  { "trace", required_argument, 0, 'n' },
-  { "rlogin", no_argument, 0, 'r' },
-  { "disable-auth", required_argument, 0, 'X' },
-  { "encrypt", no_argument, 0, 'x' },
-  { "fwd-credentials", no_argument, 0, 'f' },
-  { "realm", required_argument, 0, 'k' },
-  { "transcom", required_argument, 0, 't' },
-  { "help", no_argument, 0, '&' },
-  { "version", no_argument, 0, 'V' },
-  { 0 }
+static struct option long_options[] = {
+  {"ipv4", no_argument, 0, '4'},
+  {"ipv6", no_argument, 0, '6'},
+  {"binary", no_argument, 0, '8'},
+  {"login", no_argument, 0, 'a'},
+  {"no-rc", no_argument, 0, 'c'},
+  {"debug", no_argument, 0, 'd'},
+  {"escape", required_argument, 0, 'e'},
+  {"no-escape", no_argument, 0, 'E'},
+  {"no-login", no_argument, 0, 'K'},
+  {"user", required_argument, 0, 'l'},
+  {"binary-output", no_argument, 0, 'L'},
+  {"trace", required_argument, 0, 'n'},
+  {"rlogin", no_argument, 0, 'r'},
+  {"disable-auth", required_argument, 0, 'X'},
+  {"encrypt", no_argument, 0, 'x'},
+  {"fwd-credentials", no_argument, 0, 'f'},
+  {"realm", required_argument, 0, 'k'},
+  {"transcom", required_argument, 0, 't'},
+  {"help", no_argument, 0, '&'},
+  {"version", no_argument, 0, 'V'},
+  {0}
 };
 
 /*
  * main.  Parse arguments, invoke the protocol or command parser.
  */
 int
-main(int argc, char *argv[])
+main (int argc, char *argv[])
 {
-	extern char *optarg;
-	extern int optind;
-	int ch;
-	int family = 0;
-	char *user;
+  extern char *optarg;
+  extern int optind;
+  int ch;
+  int family = 0;
+  char *user;
 #ifndef strrchr
-	char *strrchr();
+  char *strrchr ();
 #endif
 #ifdef	FORWARD
-	extern int forward_flags;
-#endif	/* FORWARD */
+  extern int forward_flags;
+#endif /* FORWARD */
 
-	tninit();		/* Clear out things */
-#if	defined(CRAY) && !defined(__STDC__)
-	_setlist_init();	/* Work around compiler bug */
+  tninit ();			/* Clear out things */
+#if defined(CRAY) && !defined(__STDC__)
+  _setlist_init ();		/* Work around compiler bug */
 #endif
 
-	TerminalSaveState();
+  TerminalSaveState ();
 
-	if (prompt = strrchr(argv[0], '/'))
-		++prompt;
-	else
-		prompt = argv[0];
+  if (prompt = strrchr (argv[0], '/'))
+    ++prompt;
+  else
+    prompt = argv[0];
 
-	user = NULL;
+  user = NULL;
 
-	rlogin = (strncmp(prompt, "rlog", 4) == 0) ? '~' : _POSIX_VDISABLE;
-	autologin = -1;
+  rlogin = (strncmp (prompt, "rlog", 4) == 0) ? '~' : _POSIX_VDISABLE;
+  autologin = -1;
 
-	while ((ch = getopt_long (argc, argv, "468EKLS:X:acde:fFk:l:n:rt:x",
-				  long_options, 0))
-	       != EOF)
+  while ((ch = getopt_long (argc, argv, "468EKLS:X:acde:fFk:l:n:rt:x",
+			    long_options, 0)) != EOF)
+    {
+      switch (ch)
 	{
-		switch(ch) {
-		case '4':
-			family = 4;
-			break;
+	case '4':
+	  family = 4;
+	  break;
 
-		case '6':
-			family = 6;
-			break;
-			
-		case '8':
-			eight = 3;	/* binary output and input */
-			break;
-		case 'E':
-			rlogin = escape = _POSIX_VDISABLE;
-			break;
-		case 'K':
+	case '6':
+	  family = 6;
+	  break;
+
+	case '8':
+	  eight = 3;		/* binary output and input */
+	  break;
+	case 'E':
+	  rlogin = escape = _POSIX_VDISABLE;
+	  break;
+	case 'K':
 #ifdef	AUTHENTICATION
-			autologin = 0;
+	  autologin = 0;
 #endif
-			break;
-		case 'L':
-			eight |= 2;	/* binary output only */
-			break;
-		case 'X':
+	  break;
+	case 'L':
+	  eight |= 2;		/* binary output only */
+	  break;
+	case 'X':
 #ifdef	AUTHENTICATION
-			auth_disable_name(optarg);
+	  auth_disable_name (optarg);
 #endif
-			break;
-		case 'a':
-			autologin = 1;
-			break;
-		case 'c':
-			skiprc = 1;
-			break;
-		case 'd':
-			debug = 1;
-			break;
-		case 'e':
-			set_escape_char(optarg);
-			break;
-		case 'f':
+	  break;
+	case 'a':
+	  autologin = 1;
+	  break;
+	case 'c':
+	  skiprc = 1;
+	  break;
+	case 'd':
+	  debug = 1;
+	  break;
+	case 'e':
+	  set_escape_char (optarg);
+	  break;
+	case 'f':
 #if defined(AUTHENTICATION) && defined(KRB5) && defined(FORWARD)
-			if (forward_flags & OPTS_FORWARD_CREDS) {
-			    fprintf(stderr,
-				    "%s: Only one of -f and -F allowed.\n",
-				    prompt);
-			    help (0);
-			}
-			forward_flags |= OPTS_FORWARD_CREDS;
+	  if (forward_flags & OPTS_FORWARD_CREDS)
+	    {
+	      fprintf (stderr,
+		       "%s: Only one of -f and -F allowed.\n", prompt);
+	      help (0);
+	    }
+	  forward_flags |= OPTS_FORWARD_CREDS;
 #else
-			fprintf(stderr,
-			 "%s: Warning: -f ignored, no Kerberos V5 support.\n",
-				prompt);
+	  fprintf (stderr,
+		   "%s: Warning: -f ignored, no Kerberos V5 support.\n",
+		   prompt);
 #endif
-			break;
-		case 'F':
+	  break;
+	case 'F':
 #if defined(AUTHENTICATION) && defined(KRB5) && defined(FORWARD)
-			if (forward_flags & OPTS_FORWARD_CREDS) {
-			    fprintf(stderr,
-				    "%s: Only one of -f and -F allowed.\n",
-				    prompt);
-			    help (0);
-			}
-			forward_flags |= OPTS_FORWARD_CREDS;
-			forward_flags |= OPTS_FORWARDABLE_CREDS;
+	  if (forward_flags & OPTS_FORWARD_CREDS)
+	    {
+	      fprintf (stderr,
+		       "%s: Only one of -f and -F allowed.\n", prompt);
+	      help (0);
+	    }
+	  forward_flags |= OPTS_FORWARD_CREDS;
+	  forward_flags |= OPTS_FORWARDABLE_CREDS;
 #else
-			fprintf(stderr,
-			 "%s: Warning: -F ignored, no Kerberos V5 support.\n",
-				prompt);
+	  fprintf (stderr,
+		   "%s: Warning: -F ignored, no Kerberos V5 support.\n",
+		   prompt);
 #endif
-			break;
-		case 'k':
+	  break;
+	case 'k':
 #if defined(AUTHENTICATION) && defined(KRB4)
-		    {
-			extern char *dest_realm, dst_realm_buf[], dst_realm_sz;
-			dest_realm = dst_realm_buf;
-			(void)strncpy(dest_realm, optarg, dst_realm_sz);
-		    }
+	  {
+	    extern char *dest_realm, dst_realm_buf[], dst_realm_sz;
+	    dest_realm = dst_realm_buf;
+	    strncpy (dest_realm, optarg, dst_realm_sz);
+	  }
 #else
-			fprintf(stderr,
-			   "%s: Warning: -k ignored, no Kerberos V4 support.\n",
-								prompt);
+	  fprintf (stderr,
+		   "%s: Warning: -k ignored, no Kerberos V4 support.\n",
+		   prompt);
 #endif
-			break;
-		case 'l':
-			autologin = 1;
-			user = optarg;
-			break;
-		case 'n':
+	  break;
+	case 'l':
+	  autologin = 1;
+	  user = optarg;
+	  break;
+	case 'n':
 #if defined(TN3270) && defined(unix)
-			/* distinguish between "-n oasynch" and "-noasynch" */
-			if (argv[optind - 1][0] == '-' && argv[optind - 1][1]
-			    == 'n' && argv[optind - 1][2] == 'o') {
-				if (!strcmp(optarg, "oasynch")) {
-					noasynchtty = 1;
-					noasynchnet = 1;
-				} else if (!strcmp(optarg, "oasynchtty"))
-					noasynchtty = 1;
-				else if (!strcmp(optarg, "oasynchnet"))
-					noasynchnet = 1;
-			} else
-#endif	/* defined(TN3270) && defined(unix) */
-				SetNetTrace(optarg);
-			break;
-		case 'r':
-			rlogin = '~';
-			break;
-		case 't':
+	  /* distinguish between "-n oasynch" and "-noasynch" */
+	  if (argv[optind - 1][0] == '-' && argv[optind - 1][1]
+	      == 'n' && argv[optind - 1][2] == 'o')
+	    {
+	      if (!strcmp (optarg, "oasynch"))
+		{
+		  noasynchtty = 1;
+		  noasynchnet = 1;
+		}
+	      else if (!strcmp (optarg, "oasynchtty"))
+		noasynchtty = 1;
+	      else if (!strcmp (optarg, "oasynchnet"))
+		noasynchnet = 1;
+	    }
+	  else
+#endif /* defined(TN3270) && defined(unix) */
+	    SetNetTrace (optarg);
+	  break;
+	case 'r':
+	  rlogin = '~';
+	  break;
+	case 't':
 #if defined(TN3270) && defined(unix)
-			transcom = tline;
-			(void)strcpy(transcom, optarg);
+	  transcom = tline;
+	  strcpy (transcom, optarg);
 #else
-			fprintf(stderr,
-			   "%s: Warning: -t ignored, no TN3270 support.\n",
-								prompt);
+	  fprintf (stderr,
+		   "%s: Warning: -t ignored, no TN3270 support.\n", prompt);
 #endif
-			break;
-		case 'x':
+	  break;
+	case 'x':
 #ifdef	ENCRYPTION
-			encrypt_auto(1);
-			decrypt_auto(1);
-#else	/* ENCRYPTION */
-			fprintf(stderr,
-			    "%s: Warning: -x ignored, no ENCRYPT support.\n",
-								prompt);
-#endif	/* ENCRYPTION */
-			break;
+	  encrypt_auto (1);
+	  decrypt_auto (1);
+#else /* ENCRYPTION */
+	  fprintf (stderr,
+		   "%s: Warning: -x ignored, no ENCRYPT support.\n", prompt);
+#endif /* ENCRYPTION */
+	  break;
 
-		case '&':
-			help ();
-		case 'V':
-			printf ("telnet (%s) %s\n",
-				PACKAGE_NAME, PACKAGE_VERSION);
-			exit (0);
+	case '&':
+	  help ();
+	case 'V':
+	  printf ("telnet (%s) %s\n", PACKAGE_NAME, PACKAGE_VERSION);
+	  exit (0);
 
-		case '?':
-			try_help ();
+	case '?':
+	  try_help ();
 
-		default:
-			usage ();
-			/* NOTREACHED */
-		}
+	default:
+	  usage ();
 	}
-	if (autologin == -1)
-		autologin = (rlogin == _POSIX_VDISABLE) ? 0 : 1;
+    }
+  if (autologin == -1)
+    autologin = (rlogin == _POSIX_VDISABLE) ? 0 : 1;
 
-	argc -= optind;
-	argv += optind;
+  argc -= optind;
+  argv += optind;
 
-	if (argc) {
-		char *args[8], **argp = args;
+  if (argc)
+    {
+      char *args[8], **argp = args;
 
-		if (argc > 2)
-			usage ();
-		*argp++ = prompt;
-		if (user) {
-			*argp++ = "-l";
-			*argp++ = user;
-		}
-		if (family == 4)
-		  *argp++ = "-4";
-		else if (family == 6)
-		  *argp++ = "-6";
-
-		*argp++ = argv[0];		/* host */
-		if (argc > 1)
-			*argp++ = argv[1];	/* port */
-		*argp = 0;
-
-		if (setjmp(toplevel) != 0)
-			Exit(0);
-		if (tn(argp - args, args) == 1)
-			return (0);
-		else
-			return (1);
+      if (argc > 2)
+	usage ();
+      *argp++ = prompt;
+      if (user)
+	{
+	  *argp++ = "-l";
+	  *argp++ = user;
 	}
-	(void)setjmp(toplevel);
-	for (;;) {
+      if (family == 4)
+	*argp++ = "-4";
+      else if (family == 6)
+	*argp++ = "-6";
+
+      *argp++ = argv[0];	/* host */
+      if (argc > 1)
+	*argp++ = argv[1];	/* port */
+      *argp = 0;
+
+      if (setjmp (toplevel) != 0)
+	Exit (0);
+      if (tn (argp - args, args) == 1)
+	return (0);
+      else
+	return (1);
+    }
+  setjmp (toplevel);
+  for (;;)
+    {
 #ifdef TN3270
-		if (shell_active)
-			shell_continue();
-		else
+      if (shell_active)
+	shell_continue ();
+      else
 #endif
-			command(1, 0, 0);
-	}
+	command (1, 0, 0);
+    }
 }
