@@ -27,14 +27,12 @@
  * SUCH DAMAGE.
  */
 
-#ifndef lint
-static char sccsid[] = "@(#)network.c	8.2 (Berkeley) 12/15/93";
-#endif /* not lint */
-
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
+#include <stdlib.h>
+
 #include <sys/types.h>
 #include <sys/socket.h>
 #ifdef TIME_WITH_SYS_TIME
@@ -52,7 +50,7 @@ static char sccsid[] = "@(#)network.c	8.2 (Berkeley) 12/15/93";
 
 #include <arpa/telnet.h>
 #ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>
+# include <sys/select.h>
 #endif
 
 #include "ring.h"
@@ -61,23 +59,25 @@ static char sccsid[] = "@(#)network.c	8.2 (Berkeley) 12/15/93";
 #include "externs.h"
 #include "fdset.h"
 
-Ring		netoring, netiring;
-unsigned char	netobuf[2*BUFSIZ], netibuf[BUFSIZ];
+Ring netoring, netiring;
+unsigned char netobuf[2 * BUFSIZ], netibuf[BUFSIZ];
 
 /*
  * Initialize internal network data structures.
  */
 
 void
-init_network()
+init_network ()
 {
-    if (ring_init(&netoring, netobuf, sizeof netobuf) != 1) {
-	exit(1);
+  if (ring_init (&netoring, netobuf, sizeof netobuf) != 1)
+    {
+      exit (1);
     }
-    if (ring_init(&netiring, netibuf, sizeof netibuf) != 1) {
-	exit(1);
+  if (ring_init (&netiring, netibuf, sizeof netibuf) != 1)
+    {
+      exit (1);
     }
-    NetTrace = stdout;
+  NetTrace = stdout;
 }
 
 
@@ -87,27 +87,33 @@ init_network()
  */
 
 int
-stilloob()
+stilloob ()
 {
-    static struct timeval timeout = { 0 };
-    fd_set	excepts;
-    int value;
+  static struct timeval timeout = { 0 };
+  fd_set excepts;
+  int value;
 
-    do {
-	FD_ZERO(&excepts);
-	FD_SET(net, &excepts);
-	value = select(net+1, (fd_set *)0, (fd_set *)0, &excepts, &timeout);
-    } while ((value == -1) && (errno == EINTR));
-
-    if (value < 0) {
-	perror("select");
-	(void) quit();
-	/* NOTREACHED */
+  do
+    {
+      FD_ZERO (&excepts);
+      FD_SET (net, &excepts);
+      value =
+	select (net + 1, (fd_set *) 0, (fd_set *) 0, &excepts, &timeout);
     }
-    if (FD_ISSET(net, &excepts)) {
-	return 1;
-    } else {
-	return 0;
+  while ((value == -1) && (errno == EINTR));
+
+  if (value < 0)
+    {
+      perror ("select");
+      (void) quit ();
+    }
+  if (FD_ISSET (net, &excepts))
+    {
+      return 1;
+    }
+  else
+    {
+      return 0;
     }
 }
 
@@ -119,9 +125,9 @@ stilloob()
  */
 
 void
-setneturg()
+setneturg ()
 {
-    ring_mark(&netoring);
+  ring_mark (&netoring);
 }
 
 
@@ -136,54 +142,64 @@ setneturg()
 
 
 int
-netflush()
+netflush ()
 {
-    register int n, n1;
+  register int n, n1;
 
 #ifdef	ENCRYPTION
-    if (encrypt_output)
-	ring_encrypt(&netoring, encrypt_output);
-#endif	/* ENCRYPTION */
-    if ((n1 = n = ring_full_consecutive(&netoring)) > 0) {
-	if (!ring_at_mark(&netoring)) {
-	    n = send(net, (char *)netoring.consume, n, 0); /* normal write */
-	} else {
-	    /*
-	     * In 4.2 (and 4.3) systems, there is some question about
-	     * what byte in a sendOOB operation is the "OOB" data.
-	     * To make ourselves compatible, we only send ONE byte
-	     * out of band, the one WE THINK should be OOB (though
-	     * we really have more the TCP philosophy of urgent data
-	     * rather than the Unix philosophy of OOB data).
-	     */
-	    n = send(net, (char *)netoring.consume, 1, MSG_OOB);/* URGENT data */
+  if (encrypt_output)
+    ring_encrypt (&netoring, encrypt_output);
+#endif /* ENCRYPTION */
+  if ((n1 = n = ring_full_consecutive (&netoring)) > 0)
+    {
+      if (!ring_at_mark (&netoring))
+	{
+	  n = send (net, (char *) netoring.consume, n, 0);	/* normal write */
+	}
+      else
+	{
+	  /*
+	   * In 4.2 (and 4.3) systems, there is some question about
+	   * what byte in a sendOOB operation is the "OOB" data.
+	   * To make ourselves compatible, we only send ONE byte
+	   * out of band, the one WE THINK should be OOB (though
+	   * we really have more the TCP philosophy of urgent data
+	   * rather than the Unix philosophy of OOB data).
+	   */
+	  n = send (net, (char *) netoring.consume, 1, MSG_OOB);	/* URGENT data */
 	}
     }
-    if (n < 0) {
-	if (errno != ENOBUFS && errno != EWOULDBLOCK) {
-	    setcommandmode();
-	    perror(hostname);
-	    (void)NetClose(net);
-	    ring_clear_mark(&netoring);
-	    longjmp(peerdied, -1);
-	    /*NOTREACHED*/
+  if (n < 0)
+    {
+      if (errno != ENOBUFS && errno != EWOULDBLOCK)
+	{
+	  setcommandmode ();
+	  perror (hostname);
+	  (void) NetClose (net);
+	  ring_clear_mark (&netoring);
+	  longjmp (peerdied, -1);
 	}
-	n = 0;
+      n = 0;
     }
-    if (netdata && n) {
-	Dump('>', netoring.consume, n);
+  if (netdata && n)
+    {
+      Dump ('>', netoring.consume, n);
     }
-    if (n) {
-	ring_consumed(&netoring, n);
-	/*
-	 * If we sent all, and more to send, then recurse to pick
-	 * up the other half.
-	 */
-	if ((n1 == n) && ring_full_consecutive(&netoring)) {
-	    (void) netflush();
+  if (n)
+    {
+      ring_consumed (&netoring, n);
+      /*
+       * If we sent all, and more to send, then recurse to pick
+       * up the other half.
+       */
+      if ((n1 == n) && ring_full_consecutive (&netoring))
+	{
+	  (void) netflush ();
 	}
-	return 1;
-    } else {
-	return 0;
+      return 1;
+    }
+  else
+    {
+      return 0;
     }
 }
