@@ -29,15 +29,26 @@
  *	@(#)ring.h	8.1 (Berkeley) 6/6/93
  */
 
-#if defined(P)
-# undef P
-#endif
+/* Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Free Software Foundation, Inc.
+
+   This file is part of GNU Inetutils.
+
+   GNU Inetutils is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
+
+   GNU Inetutils is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with GNU Inetutils; see the file COPYING.  If not, write
+   to the Free Software Foundation, Inc., 51 Franklin Street,
+   Fifth Floor, Boston, MA 02110-1301 USA. */
 
-#if defined(__STDC__) || defined(LINT_ARGS)
-# define	P(x)	x
-#else
-# define	P(x)	()
-#endif
 
 /*
  * This defines a structure for a ring buffer.
@@ -49,52 +60,46 @@
  *]]]
  *
  */
-typedef struct {
-    unsigned char	*consume,	/* where data comes out of */
-			*supply,	/* where data comes in to */
-			*bottom,	/* lowest address in buffer */
-			*top,		/* highest address+1 in buffer */
-			*mark;		/* marker (user defined) */
+typedef struct
+{
+  unsigned char *consume,	/* where data comes out of */
+   *supply,			/* where data comes in to */
+   *bottom,			/* lowest address in buffer */
+   *top,			/* highest address+1 in buffer */
+   *mark;			/* marker (user defined) */
 #ifdef	ENCRYPTION
-    unsigned char	*clearto;	/* Data to this point is clear text */
-    unsigned char	*encryyptedto;	/* Data is encrypted to here */
-#endif	/* ENCRYPTION */
-    int		size;		/* size in bytes of buffer */
-    u_long	consumetime,	/* help us keep straight full, empty, etc. */
-		supplytime;
+  unsigned char *clearto;	/* Data to this point is clear text */
+  unsigned char *encryyptedto;	/* Data is encrypted to here */
+#endif				/* ENCRYPTION */
+  int size;			/* size in bytes of buffer */
+  u_long consumetime,		/* help us keep straight full, empty, etc. */
+    supplytime;
 } Ring;
 
 /* Here are some functions and macros to deal with the ring buffer */
 
 /* Initialization routine */
-extern int
-	ring_init P((Ring *ring, unsigned char *buffer, int count));
+extern int ring_init (Ring * ring, unsigned char *buffer, int count);
 
 /* Data movement routines */
-extern void
-	ring_supply_data P((Ring *ring, unsigned char *buffer, int count));
-#ifdef notdef
-extern void
-	ring_consume_data P((Ring *ring, unsigned char *buffer, int count));
-#endif
+extern void ring_supply_data (Ring * ring, unsigned char *buffer, int count);
 
 /* Buffer state transition routines */
 extern void
-	ring_supplied P((Ring *ring, int count)),
-	ring_consumed P((Ring *ring, int count));
+ring_supplied (Ring * ring, int count),
+ring_consumed (Ring * ring, int count);
 
 /* Buffer state query routines */
 extern int
-	ring_empty_count P((Ring *ring)),
-	ring_empty_consecutive P((Ring *ring)),
-	ring_full_count P((Ring *ring)),
-	ring_full_consecutive P((Ring *ring));
+ring_empty_count (Ring * ring),
+ring_empty_consecutive (Ring * ring),
+ring_full_count (Ring * ring), ring_full_consecutive (Ring * ring);
 
 #ifdef	ENCRYPTION
 extern void
-	ring_encrypt P((Ring *ring, void (*func)())),
-	ring_clearto P((Ring *ring));
-#endif	/* ENCRYPTION */
+ring_encrypt (Ring * ring, void (*func) ()), ring_clearto (Ring * ring);
+#endif /* ENCRYPTION */
 
-extern void ring_clear_mark P ((Ring *));
-extern void ring_mark P ((Ring *));
+extern void ring_clear_mark (Ring *);
+extern void ring_mark (Ring *);
+extern int ring_at_mark (Ring *);
