@@ -29,20 +29,21 @@
  *	@(#)types.h	8.1 (Berkeley) 6/6/93
  */
 
-typedef struct {
-    char *modedescriptions;
-    char modetype;
+typedef struct
+{
+  char *modedescriptions;
+  char modetype;
 } Modelist;
 
 extern Modelist modelist[];
 
-typedef struct {
-    int
-	system,			/* what the current time is */
-	echotoggle,		/* last time user entered echo character */
-	modenegotiated,		/* last time operating mode negotiated */
-	didnetreceive,		/* last time we read data from network */
-	gotDM;			/* when did we last see a data mark */
+typedef struct
+{
+  int system,			/* what the current time is */
+    echotoggle,			/* last time user entered echo character */
+    modenegotiated,		/* last time operating mode negotiated */
+    didnetreceive,		/* last time we read data from network */
+    gotDM;			/* when did we last see a data mark */
 } Clocks;
 
 extern Clocks clocks;
