@@ -30,14 +30,25 @@
  * SUCH DAMAGE.
  */
 
-#ifndef lint
-static char copyright[] = "@(#) Copyright (c) 1985, 1993\n\
-	The Regents of the University of California.  All rights reserved.\n";
-#endif /* not lint */
+/* Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Free Software Foundation, Inc.
 
-#ifndef lint
-static char sccsid[] = "@(#)uucpd.c	8.1 (Berkeley) 6/4/93";
-#endif /* not lint */
+   This file is part of GNU Inetutils.
+
+   GNU Inetutils is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
+
+   GNU Inetutils is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with GNU Inetutils; see the file COPYING.  If not, write
+   to the Free Software Foundation, Inc., 51 Franklin Street,
+   Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /*
  * 4.2BSD TCP/IP server for uucico
@@ -45,12 +56,12 @@ static char sccsid[] = "@(#)uucpd.c	8.1 (Berkeley) 6/4/93";
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
 #include <sys/types.h>
 #ifdef HAVE_SYS_WAIT_H
-#include <sys/wait.h>
+# include <sys/wait.h>
 #endif
 #include <sys/ioctl.h>
 #include <sys/socket.h>
@@ -112,7 +123,10 @@ int
 main (int argc, char **argv)
 {
 #ifndef BSDINETD
-  register int s, tcp_socket;
+  register int s;
+# ifdef BSD4_2
+  register int tcp_socket;
+# endif
   struct servent *sp;
 #endif /* !BSDINETD */
   extern int errno;
@@ -170,7 +184,7 @@ main (int argc, char **argv)
   bzero ((char *) &myctladdr, sizeof (myctladdr));
   myctladdr.sin_family = AF_INET;
   myctladdr.sin_port = sp->s_port;
-#ifdef BSD4_2
+# ifdef BSD4_2
   tcp_socket = socket (AF_INET, SOCK_STREAM, 0);
   if (tcp_socket < 0)
     {
@@ -210,11 +224,31 @@ main (int argc, char **argv)
 	}
       close (s);
     }
-#endif /* BSD4_2 */
+# endif	/* BSD4_2 */
 
 #endif /* !BSDINETD */
 }
 
+static int
+readline (register char *p, register int n)
+{
+  char c;
+
+  while (n-- > 0)
+    {
+      if (read (0, &c, 1) <= 0)
+	return (-1);
+      c &= 0177;
+      if (c == '\n' || c == '\r')
+	{
+	  *p = '\0';
+	  return (0);
+	}
+      *p++ = c;
+    }
+  return (-1);
+}
+
 void
 doit (struct sockaddr_in *sinp)
 {
@@ -274,28 +308,8 @@ doit (struct sockaddr_in *sinp)
   perror ("uucico server: execl");
 }
 
-int
-readline (register char *p, register int n)
-{
-  char c;
-
-  while (n-- > 0)
-    {
-      if (read (0, &c, 1) <= 0)
-	return (-1);
-      c &= 0177;
-      if (c == '\n' || c == '\r')
-	{
-	  *p = '\0';
-	  return (0);
-	}
-      *p++ = c;
-    }
-  return (-1);
-}
-
 #ifdef BSD4_2
-#include <fcntl.h>
+# include <fcntl.h>
 #endif /* BSD4_2 */
 
 void
@@ -310,7 +324,7 @@ dologout ()
   while ((pid = wait3 (0, WNOHANG, 0)) > 0)
 # else
   while ((pid = wait (0)) > 0)
-#endif /* HAVE_WAIT3 */
+# endif	/* HAVE_WAIT3 */
 #endif /* HAVE_WAITPID */
     {
       char line[100];
@@ -327,7 +341,7 @@ dologin (struct passwd *pw, struct sockaddr_in *sin)
 {
   char line[32];
   char remotehost[32];
-  int wtmp, f;
+  int f;
   struct hostent *hp = gethostbyaddr ((char *) &sin->sin_addr,
 				      sizeof (struct in_addr), AF_INET);
 
@@ -344,7 +358,7 @@ dologin (struct passwd *pw, struct sockaddr_in *sin)
   logwtmp (line, pw->pw_name, remotehost);
 
 #if defined (PATH_LASTLOG) && defined (HAVE_STRUCT_LASTLOG)
-#define	SCPYN(a, b)	strncpy(a, b, sizeof (a))
+# define SCPYN(a, b)	strncpy(a, b, sizeof (a))
   if ((f = open (PATH_LASTLOG, O_RDWR)) >= 0)
     {
       struct lastlog ll;
